@@ -28,7 +28,7 @@ void AlignStack::Start(size_t span, int thresh)
    stackID = get_A_Number();   // for debugging purpose only
 
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
 
    //LOG_FMT(LAS, "AlignStack::Start(%d):m_aligned.Reset()\n", __LINE__);
    m_aligned.Reset();
@@ -54,13 +54,13 @@ void AlignStack::Start(size_t span, int thresh)
    m_right_align = false;
    m_star_style  = SS_IGNORE;
    m_amp_style   = SS_IGNORE;
-}
+} // AlignStack::Start
 
 
 void AlignStack::ReAddSkipped()
 {
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
 
    if (m_skipped.Empty())
    {
@@ -80,17 +80,17 @@ void AlignStack::ReAddSkipped()
    }
 
    NewLines(0); // Check to see if we need to flush right away
-}
+} // AlignStack::ReAddSkipped
 
 
 void AlignStack::Add(Chunk *start, size_t seqnum)
 {
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
    LOG_FUNC_ENTRY();
 
-   LOG_FMT(LAS, "AlignStack::%s(%d): Candidate is '%s': orig_line is %zu, column is %zu, type is %s, level is %zu\n",
-           __func__, __LINE__, start->Text(), start->orig_line, start->column, get_token_name(start->type), start->level);
+   LOG_FMT(LAS, "AlignStack::%s(%d): Candidate is '%s': orig line is %zu, column is %zu, type is %s, level is %zu\n",
+           __func__, __LINE__, start->Text(), start->GetOrigLine(), start->GetColumn(), get_token_name(start->GetType()), start->GetLevel());
    LOG_FMT(LAS, "AlignStack::%s(%d): seqnum is %zu\n", __func__, __LINE__, seqnum);
 
    // Assign a seqnum if needed
@@ -170,38 +170,27 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
    LOG_FMT(LAS, "AlignStack::%s(%d): m_star_style is %s\n",
            __func__, __LINE__, get_StarStyle_name(m_star_style));
    // Find ref. Back up to the real item that is aligned.
-   Chunk *prev = Chunk::NullChunkPtr;
+   Chunk *prev = start;
 
-   if (start != nullptr)
-   {
-      prev = start;
-   }
-
-   while (  (prev = prev->GetPrev()) != nullptr
-         && prev->IsNotNullChunk()
-         && (  chunk_is_ptr_operator(prev)
-            || chunk_is_token(prev, CT_TPAREN_OPEN)))
+   while (  (prev = prev->GetPrev())->IsNotNullChunk()
+         && (  prev->IsPointerOperator()
+            || prev->Is(CT_TPAREN_OPEN)))
    {
       // do nothing - we want prev when this exits
    }
 
-   if (prev == nullptr)
+   if (prev->IsNullChunk())
    {
       return;
    }
    Chunk *ref = prev;
 
-   if (chunk_is_newline(ref))
+   if (ref->IsNewline())
    {
       ref = ref->GetNext();
    }
    // Find the item that we are going to align.
-   Chunk *ali = Chunk::NullChunkPtr;
-
-   if (start != nullptr)
-   {
-      ali = start;
-   }
+   Chunk *ali = start;
 
    if (m_star_style != SS_IGNORE)
    {
@@ -209,13 +198,13 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
       Chunk *tmp_prev = ali->GetPrev();
 
       while (  tmp_prev->IsStar()
-            || chunk_is_msref(tmp_prev))
+            || tmp_prev->IsMsRef())
       {
          ali      = tmp_prev;
          tmp_prev = ali->GetPrev();
       }
 
-      if (chunk_is_token(tmp_prev, CT_TPAREN_OPEN))
+      if (tmp_prev->Is(CT_TPAREN_OPEN))
       {
          ali      = tmp_prev;
          tmp_prev = ali->GetPrev();
@@ -230,20 +219,22 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
       // back up to the first '&' preceding the token
       Chunk *tmp_prev = ali->GetPrev();
 
-      while (chunk_is_addr(tmp_prev))
+      while (tmp_prev->IsAddress())
       {
          ali      = tmp_prev;
          tmp_prev = ali->GetPrev();
       }
    }
+   LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: ali orig line is %zu, orig col is %zu, Text() '%s', level is %zu, type is %s\n",
+           __func__, __LINE__, ali->GetOrigLine(), ali->GetOrigCol(), ali->Text(), ali->GetLevel(), get_token_name(ali->GetType()));
    log_rule_B("align_keep_extra_space");
 
    // Tighten down the spacing between ref and start
    if (!options::align_keep_extra_space())
    {
-      size_t tmp_col = ref->column;
+      size_t tmp_col = ref->GetColumn();
       Chunk  *tmp    = ref;
-      LOG_FMT(LAS, "AlignStack::%s(%d): tmp_col is %zu\n",
+      LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: tmp_col is %zu\n",
               __func__, __LINE__, tmp_col);
 
       while (  tmp->IsNotNullChunk()
@@ -253,28 +244,29 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
 
          if (next->IsNotNullChunk())
          {
-            LOG_FMT(LAS, "AlignStack::%s(%d): next->orig_line is %zu, orig_col is %zu, Text() '%s', level is %zu, type is %s\n",
-                    __func__, __LINE__, next->orig_line, next->orig_col, next->Text(), next->level, get_token_name(next->type));
+            LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: next orig line is %zu, orig col is %zu, Text() '%s', level is %zu, type is %s\n",
+                    __func__, __LINE__, next->GetOrigLine(), next->GetOrigCol(), next->Text(), next->GetLevel(), get_token_name(next->GetType()));
             tmp_col += space_col_align(tmp, next);
-            LOG_FMT(LAS, "AlignStack::%s(%d): next->column is %zu, level is %zu, tmp_col is %zu\n",
-                    __func__, __LINE__, next->column, next->level, tmp_col);
+            LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: next column is %zu, level is %zu, tmp_col is %zu\n",
+                    __func__, __LINE__, next->GetColumn(), next->GetLevel(), tmp_col);
 
-            if (next->column != tmp_col)
+            if (next->GetColumn() != tmp_col)
             {
-               LOG_FMT(LAS, "AlignStack::%s(%d): Call align_to_column\n", __func__, __LINE__);
+               LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: Call align_to_column\n", __func__, __LINE__);
                align_to_column(next, tmp_col);
             }
          }
          tmp = next;
       }
    }
+   LOG_FMT(LAS, "AlignStack::%s(%3d): GUY:\n", __func__, __LINE__);
 
    // Check threshold limits
    if (  m_max_col == 0
       || m_thresh == 0
-      || (  ((start->column + m_gap) <= (m_thresh + (m_absolute_thresh ? m_min_col : m_max_col))) // don't use subtraction here to prevent underflow
-         && (  (start->column + m_gap + m_thresh) >= m_max_col                                    // change the expression to mind negative expression
-            || start->column >= m_min_col)))
+      || (  ((start->GetColumn() + m_gap) <= (m_thresh + (m_absolute_thresh ? m_min_col : m_max_col))) // don't use subtraction here to prevent underflow
+         && (  (start->GetColumn() + m_gap + m_thresh) >= m_max_col                                    // change the expression to mind negative expression
+            || start->GetColumn() >= m_min_col)))
    {
       // we are adding it, so update the newline seqnum
       if (seqnum > m_nl_seqnum)
@@ -287,50 +279,50 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
 
       if (ref != ali)
       {
-         gap = ali->column - (ref->column + ref->Len());
+         gap = ali->GetColumn() - (ref->GetColumn() + ref->Len());
       }
       Chunk *tmp = ali;
 
-      if (chunk_is_token(tmp, CT_TPAREN_OPEN))
+      if (tmp->Is(CT_TPAREN_OPEN))
       {
          tmp = tmp->GetNext();
       }
 
       if (  (  tmp->IsStar()
             && m_star_style == SS_DANGLE)
-         || (  chunk_is_addr(tmp)
+         || (  tmp->IsAddress()
             && m_amp_style == SS_DANGLE)
-         || (  chunk_is_nullable(tmp)
+         || (  tmp->IsNullable()
             && (m_star_style == SS_DANGLE))
-         || (  chunk_is_msref(tmp)
+         || (  tmp->IsMsRef()
             && m_star_style == SS_DANGLE))     // TODO: add m_msref_style
       {
-         col_adj = start->column - ali->column;
-         gap     = start->column - (ref->column + ref->Len());
+         col_adj = start->GetColumn() - ali->GetColumn();
+         gap     = start->GetColumn() - (ref->GetColumn() + ref->Len());
       }
       // See if this pushes out the max_col
-      const size_t endcol = ali->column + col_adj
+      const size_t endcol = ali->GetColumn() + col_adj
                             + (gap < m_gap ? m_gap - gap : 0);
 
-      ali->align.col_adj = col_adj;
-      ali->align.ref     = ref;
-      ali->align.start   = start;
+      ali->AlignData().col_adj = col_adj;
+      ali->AlignData().ref     = ref;
+      ali->AlignData().start   = start;
       m_aligned.Push_Back(ali, seqnum);
       m_last_added = 1;
 
       // Issue #2278
-      if (chunk_is_token(ali, CT_PTR_TYPE))
+      if (ali->Is(CT_PTR_TYPE))
       {
-         LOG_FMT(LAS, "AlignStack::%s(%d): Add-[%s][%s]: ali->orig_line is %zu, column is %zu, type is %s, level is %zu\n",
-                 __func__, __LINE__, ali->Text(), start->Text(), ali->orig_line, ali->column, get_token_name(ali->type), ali->level);
+         LOG_FMT(LAS, "AlignStack::%s(%d): Add-[%s][%s]: ali orig line is %zu, column is %zu, type is %s, level is %zu\n",
+                 __func__, __LINE__, ali->Text(), start->Text(), ali->GetOrigLine(), ali->GetColumn(), get_token_name(ali->GetType()), ali->GetLevel());
       }
       else
       {
-         LOG_FMT(LAS, "AlignStack::%s(%d): Add-[%s]: ali->orig_line is %zu, column is %zu, type is %s, level is %zu\n",
-                 __func__, __LINE__, ali->Text(), ali->orig_line, ali->column, get_token_name(ali->type), ali->level);
+         LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: Add-[%s]: ali orig line is %zu, column is %zu, type is %s, level is %zu\n",
+                 __func__, __LINE__, ali->Text(), ali->GetOrigLine(), ali->GetColumn(), get_token_name(ali->GetType()), ali->GetLevel());
       }
-      LOG_FMT(LAS, "AlignStack::%s(%d):    ali->align.col_adj is %d, ref '%s', endcol is %zu\n",
-              __func__, __LINE__, ali->align.col_adj, ref->Text(), endcol);
+      LOG_FMT(LAS, "AlignStack::%s(%3d): GUY:    ali alignment col_adj is %d, ref '%s', endcol is %zu\n",
+              __func__, __LINE__, ali->GetAlignData().col_adj, ref->Text(), endcol);
 
       if (m_min_col > endcol)
       {
@@ -339,10 +331,10 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
 
       if (endcol > m_max_col)
       {
-         LOG_FMT(LAS, "AlignStack::%s(%d): Add-aligned: seqnum is %zu, m_nl_seqnum is %zu, m_seqnum is %zu\n",
+         LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: Add-aligned: seqnum is %zu, m_nl_seqnum is %zu, m_seqnum is %zu\n",
                  __func__, __LINE__, seqnum, m_nl_seqnum, m_seqnum);
-         LOG_FMT(LAS, "AlignStack::%s(%d):    ali->orig_line is %zu, ali->column is %zu, max_col old is %zu, new is %zu, m_min_col is %zu\n",
-                 __func__, __LINE__, ali->orig_line, ali->column, m_max_col, endcol, m_min_col);
+         LOG_FMT(LAS, "AlignStack::%s(%3d): GUY:    ali orig line is %zu, column is %zu, max_col old is %zu, new is %zu, m_min_col is %zu\n",
+                 __func__, __LINE__, ali->GetOrigLine(), ali->GetColumn(), m_max_col, endcol, m_min_col);
          m_max_col = endcol;
 
          /*
@@ -351,16 +343,19 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
           */
          if (!m_skipped.Empty())
          {
+            LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: ReAddSkipped()\n", __func__, __LINE__);
             ReAddSkipped();
          }
+         LOG_FMT(LAS, "AlignStack::%s(%3d): GUY:\n", __func__, __LINE__);
       }
       else
       {
-         LOG_FMT(LAS, "AlignStack::%s(%d): Add-aligned: seqnum is %zu, m_nl_seqnum is %zu, m_seqnum is %zu\n",
+         LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: Add-aligned: seqnum is %zu, m_nl_seqnum is %zu, m_seqnum is %zu\n",
                  __func__, __LINE__, seqnum, m_nl_seqnum, m_seqnum);
-         LOG_FMT(LAS, "AlignStack::%s(%d):    ali->orig_line is %zu, ali->column is %zu, max_col old is %zu, new is %zu, m_min_col is %zu\n",
-                 __func__, __LINE__, ali->orig_line, ali->column, m_max_col, endcol, m_min_col);
+         LOG_FMT(LAS, "AlignStack::%s(%3d): GUY:    ali orig line is %zu, column is %zu, max_col old is %zu, new is %zu, m_min_col is %zu\n",
+                 __func__, __LINE__, ali->GetOrigLine(), ali->GetColumn(), m_max_col, endcol, m_min_col);
       }
+      LOG_FMT(LAS, "AlignStack::%s(%3d): GUY:\n", __func__, __LINE__);
    }
    else
    {
@@ -370,17 +365,17 @@ void AlignStack::Add(Chunk *start, size_t seqnum)
 
       LOG_FMT(LAS, "AlignStack::Add-skipped [%zu/%zu/%zu]: line %zu, col %zu <= %zu + %zu\n",
               seqnum, m_nl_seqnum, m_seqnum,
-              start->orig_line, start->column, m_max_col, m_thresh);
+              start->GetOrigLine(), start->GetColumn(), m_max_col, m_thresh);
    }
+   LOG_FMT(LAS, "AlignStack::%s(%3d): GUY: End of Add\n", __func__, __LINE__);
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
 } // AlignStack::Add
 
 
 void AlignStack::NewLines(size_t cnt)
 {
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
 
    if (m_aligned.Empty())
    {
@@ -397,32 +392,36 @@ void AlignStack::NewLines(size_t cnt)
       LOG_FMT(LAS, "AlignStack::Newlines(%d): cnt is %zu\n", __LINE__, cnt);
       Flush();
    }
-}
+} // AlignStack::NewLines
 
 
 void AlignStack::Flush()
 {
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
 
    LOG_FMT(LAS, "AlignStack::%s(%d): Len() is %zu\n",
            __func__, __LINE__, Len());
 
    if (Len() > 0)
    {
-      LOG_FMT(LAS, "   (min is %zu, max is %zu)\n",
-              m_min_col, m_max_col);
+      LOG_FMT(LAS, "AlignStack::%s(%d):   min is %zu, max is %zu\n",
+              __func__, __LINE__, m_min_col, m_max_col);
+   }
+   else
+   {
+      return;
    }
 
    if (Len() == 1)
    {
       // check if we have *one* typedef in the line
       Chunk *pc   = m_aligned.Get(0)->m_pc;
-      Chunk *temp = pc->GetPrevType(CT_TYPEDEF, pc->level);
+      Chunk *temp = pc->GetPrevType(CT_TYPEDEF, pc->GetLevel());
 
       if (temp->IsNotNullChunk())
       {
-         if (pc->orig_line == temp->orig_line)
+         if (pc->GetOrigLine() == temp->GetOrigLine())
          {
             // reset the gap only for *this* stack
             m_gap = 1;
@@ -433,15 +432,14 @@ void AlignStack::Flush()
    m_max_col    = 0;
 
    // produces much more log output. Use it only debugging purpose
-   //WITH_STACKID_DEBUG;
-   LOG_FMT(LAS, "AlignStack::%s(%d): Debug the stack, Len is %zu\n",
+   LOG_FMT(LAS, "AlignStack::%s(%d): Debug the stack, Len() is %zu\n",
            __func__, __LINE__, Len());
 
    for (size_t idx = 0; idx < Len(); idx++)
    {
       Chunk *pc = m_aligned.Get(idx)->m_pc;
-      LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, pc->Text() is '%s', pc->align.col_adj is %d\n",
-              __func__, __LINE__, idx, pc->Text(), pc->align.col_adj);
+      LOG_FMT(LAS, "AlignStack::%s(%d):   idx is %zu, pc->Text() is '%s', orig line is %zu, orig col is %zu, alignment col_adj is %d\n",
+              __func__, __LINE__, idx, pc->Text(), pc->GetOrigLine(), pc->GetOrigCol(), pc->GetAlignData().col_adj);
    }
 
    // Recalculate the max_col - it may have shifted since the last Add()
@@ -453,34 +451,34 @@ void AlignStack::Flush()
       size_t col_adj = 0;
       size_t gap     = 0;
 
-      if (pc != pc->align.ref)
+      if (pc != pc->GetAlignData().ref)
       {
-         gap = pc->column - (pc->align.ref->column + pc->align.ref->Len());
+         gap = pc->GetColumn() - (pc->GetAlignData().ref->GetColumn() + pc->GetAlignData().ref->Len());
       }
 
       if (m_star_style == SS_DANGLE)
       {
-         Chunk *tmp = (chunk_is_token(pc, CT_TPAREN_OPEN)) ? pc->GetNext() : pc;
+         Chunk *tmp = (pc->Is(CT_TPAREN_OPEN)) ? pc->GetNext() : pc;
 
-         if (chunk_is_ptr_operator(tmp))
+         if (tmp->IsPointerOperator())
          {
-            col_adj = pc->align.start->column - pc->column;
-            gap     = pc->align.start->column - (pc->align.ref->column + pc->align.ref->Len());
+            col_adj = pc->GetAlignData().start->GetColumn() - pc->GetColumn();
+            gap     = pc->GetAlignData().start->GetColumn() - (pc->GetAlignData().ref->GetColumn() + pc->GetAlignData().ref->Len());
          }
       }
 
       if (m_right_align)
       {
          // Adjust the width for signed numbers
-         if (pc->align.start != nullptr)
+         if (pc->GetAlignData().start->IsNotNullChunk())
          {
-            size_t start_len = pc->align.start->Len();
+            size_t start_len = pc->GetAlignData().start->Len();
 
-            if (pc->align.start->type == CT_NEG)
+            if (pc->GetAlignData().start->GetType() == CT_NEG)
             {
-               Chunk *next = pc->align.start->GetNext();
+               Chunk *next = pc->GetAlignData().start->GetNext();
 
-               if (chunk_is_token(next, CT_NUMBER))
+               if (next->Is(CT_NUMBER))
                {
                   start_len += next->Len();
                }
@@ -488,10 +486,10 @@ void AlignStack::Flush()
             col_adj += start_len;
          }
       }
-      pc->align.col_adj = col_adj;
+      pc->AlignData().col_adj = col_adj;
 
       // See if this pushes out the max_col
-      const size_t endcol = pc->column + col_adj
+      const size_t endcol = pc->GetColumn() + col_adj
                             + (gap < m_gap ? m_gap - gap : 0);
 
       if (endcol > m_max_col)
@@ -507,50 +505,50 @@ void AlignStack::Flush()
    {
       m_max_col = align_tab_column(m_max_col);
    }
-   LOG_FMT(LAS, "AlignStack::%s(%d): Len() is %zu\n",
+   LOG_FMT(LAS, "AlignStack::%s(%d): Debug the stack, Len() is %zu\n",
            __func__, __LINE__, Len());
 
+   for (size_t idx = 0; idx < Len(); idx++)
+   {
+      Chunk *pc = m_aligned.Get(idx)->m_pc;
+      LOG_FMT(LAS, "AlignStack::%s(%d):   idx is %zu, pc->Text() is '%s', orig line is %zu, orig col is %zu, alignment col_adj is %d\n",
+              __func__, __LINE__, idx, pc->Text(), pc->GetOrigLine(), pc->GetOrigCol(), pc->GetAlignData().col_adj);
+   }
+
    const ChunkStack::Entry *ce = nullptr;
 
-   for (size_t idx = 0; idx < Len(); idx++)
-   {
-      ce = m_aligned.Get(idx);
-      LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, ce->m_pc->Text() is '%s', orig_line is %zu, orig_col is %zu, align.col_adj is %d\n",
-              __func__, __LINE__, idx, ce->m_pc->Text(), ce->m_pc->orig_line, ce->m_pc->orig_col, ce->m_pc->align.col_adj);
-   }
-
    for (size_t idx = 0; idx < Len(); idx++)
    {
       ce = m_aligned.Get(idx);
       Chunk        *pc = ce->m_pc;
 
-      const size_t tmp_col = m_max_col - pc->align.col_adj;
+      const size_t tmp_col = m_max_col - pc->GetAlignData().col_adj;
 
       if (idx == 0)
       {
          if (  m_skip_first
-            && pc->column != tmp_col)
+            && pc->GetColumn() != tmp_col)
          {
-            LOG_FMT(LAS, "AlignStack::%s(%d): orig_line is %zu, orig_col is %zu, dropping first item due to skip_first\n",
-                    __func__, __LINE__, pc->orig_line, pc->orig_col);
+            LOG_FMT(LAS, "AlignStack::%s(%d): orig line is %zu, orig col is %zu, dropping first item due to skip_first\n",
+                    __func__, __LINE__, pc->GetOrigLine(), pc->GetOrigCol());
             m_skip_first = false;
             m_aligned.Pop_Front();
             Flush();
             m_skip_first = true;
             return;
          }
-         chunk_flags_set(pc, PCF_ALIGN_START);
+         pc->SetFlagBits(PCF_ALIGN_START);
 
-         pc->align.right_align = m_right_align;
-         pc->align.amp_style   = m_amp_style;
-         pc->align.star_style  = m_star_style;
+         pc->AlignData().right_align = m_right_align;
+         pc->AlignData().amp_style   = m_amp_style;
+         pc->AlignData().star_style  = m_star_style;
       }
-      pc->align.gap  = m_gap;
-      pc->align.next = m_aligned.GetChunk(idx + 1);
+      pc->AlignData().gap  = m_gap;
+      pc->AlignData().next = m_aligned.GetChunk(idx + 1);
 
       // Indent the token, taking col_adj into account
-      LOG_FMT(LAS, "AlignStack::%s(%d): orig_line is %zu, orig_col is %zu, Text() '%s', set to col %zu (adj is %d)\n",
-              __func__, __LINE__, pc->orig_line, pc->orig_col, pc->Text(), tmp_col, pc->align.col_adj);
+      LOG_FMT(LAS, "AlignStack::%s(%d): orig line is %zu, orig col is %zu, Text() '%s', set to col %zu (adj is %d)\n",
+              __func__, __LINE__, pc->GetOrigLine(), pc->GetOrigCol(), pc->Text(), tmp_col, pc->GetAlignData().col_adj);
       align_to_column(pc, tmp_col);
    }
 
@@ -590,17 +588,17 @@ void AlignStack::Flush()
 
 void AlignStack::Reset()
 {
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
    //LOG_FMT(LAS, "AlignStack::Reset(%d):m_aligned.Reset()\n", __LINE__);
    m_aligned.Reset();
    //LOG_FMT(LAS, "AlignStack::Reset(%d):m_skipped.Reset()\n", __LINE__);
    m_skipped.Reset();
-}
+} // AlignStack::Reset
 
 
 void AlignStack::End()
 {
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
 
    if (!m_aligned.Empty())
    {
@@ -611,18 +609,19 @@ void AlignStack::End()
    m_aligned.Reset();
    //LOG_FMT(LAS, "AlignStack::End(%d):m_skipped.Reset()\n", __LINE__);
    m_skipped.Reset();
-}
+} // AlignStack::End
 
 
 size_t AlignStack::Len()
 {
+   // WITH_STACKID_DEBUG;
    return(m_aligned.Len());
-}
+} // AlignStack::Len
 
 
 void AlignStack::Debug()
 {
-   //WITH_STACKID_DEBUG;
+   // WITH_STACKID_DEBUG;
 
    size_t length = Len();
 
@@ -635,23 +634,24 @@ void AlignStack::Debug()
       {
          Chunk *pc = m_aligned.Get(idx)->m_pc;
 
-         if (chunk_is_token(pc, CT_PTR_TYPE))
+         if (pc->Is(CT_PTR_TYPE))
          {
-            LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s][%s]: orig_line is %zu, orig_col is %zu, type is %s, level is %zu, brace_level is %zu\n",
-                    __func__, __LINE__, idx, pc->Text(), pc->next->Text(), pc->orig_line, pc->orig_col, get_token_name(pc->type), pc->level, pc->brace_level);
+            LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s][%s]: orig line is %zu, orig col is %zu, type is %s, level is %zu, brace level is %zu\n",
+                    __func__, __LINE__, idx, pc->Text(), pc->GetNext()->Text(), pc->GetOrigLine(), pc->GetOrigCol(), get_token_name(pc->GetType()), pc->GetLevel(), pc->GetBraceLevel());
          }
          else
          {
-            LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s]: orig_line is %zu, orig_col is %zu, type is %s, level is %zu, brace_level is %zu\n",
-                    __func__, __LINE__, idx, pc->Text(), pc->orig_line, pc->orig_col, get_token_name(pc->type), pc->level, pc->brace_level);
+            LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s]: orig line is %zu, orig col is %zu, type is %s, level is %zu, brace level is %zu\n",
+                    __func__, __LINE__, idx, pc->Text(), pc->GetOrigLine(), pc->GetOrigCol(), get_token_name(pc->GetType()), pc->GetLevel(), pc->GetBraceLevel());
          }
       }
    }
-}
+} // AlignStack::Debug
 
 
 const char *AlignStack::get_StarStyle_name(StarStyle star_style)
 {
+   // WITH_STACKID_DEBUG;
    switch (star_style)
    {
    case StarStyle::SS_IGNORE:
@@ -664,4 +664,4 @@ const char *AlignStack::get_StarStyle_name(StarStyle star_style)
       return("SS_DANGLE");
    }
    return("?????");
-} // get_StarStyle_name
+} // AlignStack::get_StarStyle_name
