@@ -4,7 +4,7 @@
  *
  * @author  Ben Gardner
  * @author  Guy Maurel since version 0.62 for uncrustify4Qt
- *          October 2015, 2016
+ *          October 2015, 2023
  * @license GPL v2+
  */
 
@@ -14,6 +14,11 @@
 #include "prototypes.h"
 #include "uncrustify.h"
 #include "uncrustify_limits.h"
+//# define DEBUG_LANGUAGE
+// see also the call to dump_keyword_for_lang
+#ifdef DEBUG_LANGUAGE
+#include "unc_tools.h"
+#endif
 
 #include <cerrno>
 #include <map>
@@ -50,7 +55,7 @@ static const chunk_tag_t *kw_static_first(const chunk_tag_t *tag);
 static const chunk_tag_t *kw_static_match(bool orig_list, const chunk_tag_t *tag, int lang_flags);
 
 /**
- * selected keywords for the choosed language.
+ * selected keywords for the chosen language.
  */
 
 static chunk_tag_t keyword_for_lang[uncrustify::limits::MAX_KEYWORDS];
@@ -87,6 +92,11 @@ static chunk_tag_t keywords[] =
    { "API_DEPRECATED_WITH_REPLACEMENT", CT_ATTRIBUTE,        LANG_OC                                                                     },
    { "API_UNAVAILABLE",                 CT_ATTRIBUTE,        LANG_OC                                                                     },
    { "BOOL",                            CT_TYPE,             LANG_OC                                                                     },
+   { "INT16_C",                         CT_TYPE,             LANG_CPP                                                                    },
+   { "INT32_C",                         CT_TYPE,             LANG_CPP                                                                    },
+   { "INT64_C",                         CT_TYPE,             LANG_CPP                                                                    },
+   { "INT8_C",                          CT_TYPE,             LANG_CPP                                                                    },
+   { "INTMAX_C",                        CT_TYPE,             LANG_CPP                                                                    },
    { "NS_ENUM",                         CT_ENUM,             LANG_OC                                                                     },
    { "NS_OPTIONS",                      CT_ENUM,             LANG_OC                                                                     },
    { "Q_EMIT",                          CT_Q_EMIT,           LANG_CPP                                                                    },
@@ -95,6 +105,11 @@ static chunk_tag_t keywords[] =
    { "Q_GADGET",                        CT_Q_GADGET,         LANG_CPP                                                                    },
    { "Q_OBJECT",                        CT_COMMENT_EMBED,    LANG_CPP                                                                    },
    { "Q_SIGNALS",                       CT_ACCESS,           LANG_CPP                                                                    },
+   { "UINT16_C",                        CT_TYPE,             LANG_CPP                                                                    },
+   { "UINT32_C",                        CT_TYPE,             LANG_CPP                                                                    },
+   { "UINT64_C",                        CT_TYPE,             LANG_CPP                                                                    },
+   { "UINT8_C",                         CT_TYPE,             LANG_CPP                                                                    },
+   { "UINTMAX_C",                       CT_TYPE,             LANG_CPP                                                                    },
    { "_Bool",                           CT_TYPE,             LANG_C | LANG_CPP                                                           },
    { "_Complex",                        CT_TYPE,             LANG_C | LANG_CPP                                                           },
    { "_Imaginary",                      CT_TYPE,             LANG_C | LANG_CPP                                                           },
@@ -117,7 +132,7 @@ static chunk_tag_t keywords[] =
    { "__declspec",                      CT_DECLSPEC,         LANG_C | LANG_CPP                                                           },
    { "__except",                        CT_CATCH,            LANG_C | LANG_CPP                                                           },
    { "__finally",                       CT_FINALLY,          LANG_C | LANG_CPP                                                           },
-   { "__has_include",                   CT_CNG_HASINC,       LANG_C | LANG_CPP | FLAG_PP                                                 },
+   { "__has_include",                   CT_CNG_HASINC,       LANG_C | LANG_CPP | LANG_OC | FLAG_PP                                       },
    { "__has_include_next",              CT_CNG_HASINCN,      LANG_C | LANG_CPP | FLAG_PP                                                 },
    { "__inline__",                      CT_QUALIFIER,        LANG_C | LANG_CPP                                                           },
    { "__nonnull",                       CT_QUALIFIER,        LANG_OC                                                                     },
@@ -204,6 +219,7 @@ static chunk_tag_t keywords[] =
    { "endscript",                       CT_PP_ENDINPUT,      LANG_PAWN | FLAG_PP                                                         },
    { "enum",                            CT_ENUM,             LANG_ALL                                                                    },
    { "error",                           CT_PP_ERROR,         LANG_PAWN | FLAG_PP                                                         },
+   { "errordomain",                     CT_ENUM,             LANG_VALA                                                                   },
    { "event",                           CT_TYPE,             LANG_CS                                                                     },
    { "exit",                            CT_FUNCTION,         LANG_PAWN                                                                   },
    { "explicit",                        CT_QUALIFIER,        LANG_CPP | LANG_CS                                                          },
@@ -242,7 +258,7 @@ static chunk_tag_t keywords[] =
    { "instanceof",                      CT_SIZEOF,           LANG_JAVA | LANG_ECMA                                                       },
    { "int",                             CT_TYPE,             LANG_ALLC                                                                   },
    { "interface",                       CT_CLASS,            LANG_CPP | LANG_CS | LANG_D | LANG_JAVA | LANG_VALA | LANG_ECMA             },
-   { "internal",                        CT_QUALIFIER,        LANG_CS                                                                     },
+   { "internal",                        CT_QUALIFIER,        LANG_CS | LANG_VALA                                                         },
    { "invariant",                       CT_INVARIANT,        LANG_D                                                                      },
    { "ireal",                           CT_TYPE,             LANG_D                                                                      },
    { "is",                              CT_SCOMPARE,         LANG_D | LANG_CS | LANG_VALA                                                },
@@ -341,7 +357,7 @@ static chunk_tag_t keywords[] =
    { "unsigned",                        CT_TYPE,             LANG_C | LANG_CPP                                                           },
    { "ushort",                          CT_TYPE,             LANG_CS | LANG_VALA | LANG_D                                                },
    { "using",                           CT_USING,            LANG_CPP | LANG_CS | LANG_VALA                                              },
-   { "var",                             CT_TYPE,             LANG_VALA | LANG_ECMA                                                       },
+   { "var",                             CT_TYPE,             LANG_CS | LANG_VALA | LANG_ECMA                                             },
    { "version",                         CT_D_VERSION,        LANG_D                                                                      },
    { "virtual",                         CT_QUALIFIER,        LANG_CPP | LANG_CS | LANG_VALA                                              },
    { "void",                            CT_TYPE,             LANG_ALLC                                                                   },
@@ -383,8 +399,12 @@ void init_keywords_for_language()
       }
    }
 
-   LOG_FMT(LDYNKW, "%s(%d): Number of Keywords for language %d: '%zu'\n",
-           __func__, __LINE__, local_flags, language_count);
+#ifdef DEBUG_LANGUAGE
+   dump_keyword_for_lang(language_count, keyword_for_lang);
+#endif
+
+   LOG_FMT(LDYNKW, "%s(%d): Number of Keywords for language %s: '%zu'\n",
+           __func__, __LINE__, language_name_from_flags(local_flags), language_count);
 } // init_keywords_for_language
 
 
@@ -397,7 +417,7 @@ static int kw_compare(const void *p1, const void *p2)
 } // kw_compare
 
 
-bool keywords_are_sorted(void)
+bool keywords_are_sorted()
 {
    size_t keywords_count = ARRAY_SIZE(keywords);
 
@@ -408,10 +428,9 @@ bool keywords_are_sorted(void)
          fprintf(stderr, "%s: bad sort order at idx %d, words '%s' and '%s'\n",
                  __func__, (int)idx - 1, keywords[idx - 1].tag, keywords[idx].tag);
          // coveralls will always complain.
-         // these lines are only needed for the developper.
+         // these lines are only needed for the developer.
          log_flush(true);
-         cpd.error_count++;
-         return(false);
+         exit(EX_SOFTWARE);
       }
    }
 
@@ -442,7 +461,7 @@ static const chunk_tag_t *kw_static_first(const chunk_tag_t *tag)
 {
    const chunk_tag_t *prev = tag - 1;
 
-   // TODO: avoid pointer arithmetics
+   // TODO: avoid pointer arithmetic
    // loop over static keyword array
    while (  prev >= &keyword_for_lang[0]        // not at beginning of keyword array
          && strcmp(prev->tag, tag->tag) == 0)   // tags match
@@ -521,8 +540,7 @@ int load_keyword_file(const char *filename)
    {
       LOG_FMT(LERR, "%s: fopen(%s) failed: %s (%d)\n",
               __func__, filename, strerror(errno), errno);
-      cpd.error_count++;
-      return(EX_IOERR);
+      exit(EX_IOERR);
    }
    const int max_line_length = 256;
    const int max_arg_count   = 2;
@@ -557,7 +575,7 @@ int load_keyword_file(const char *filename)
          {
             LOG_FMT(LWARN, "%s:%zu Invalid line (starts with '%s')\n",
                     filename, line_no, args[0]);
-            cpd.error_count++;
+            exit(EX_SOFTWARE);
          }
       }
       else
@@ -613,7 +631,7 @@ void print_custom_keywords(FILE *pfile)
 } // print_custom_keywords
 
 
-void clear_keyword_file(void)
+void clear_keyword_file()
 {
    dkwm.clear();
 } // clear_keyword_file
