@@ -14,16 +14,11 @@
 
 using namespace uncrustify;
 
-#if defined DEBUG
 #define log_rule(rule)                                   \
    log_rule2(__func__, __LINE__, (rule), first, second); \
    log_rule4((rule), first)
-#else
-#define log_rule(rule) \
-   log_rule2(__func__, __LINE__, (rule), first, second)
-#endif
 
-// if you need more debug informations, remove the comment at the next line
+// if you need more debug information, remove the comment at the next line
 #define SUPER_LOG    1
 #ifdef SUPER_LOG
 #define log_rule_B(rule) \
@@ -33,6 +28,14 @@ using namespace uncrustify;
    log_rule3(LCURRENT, __func__, (rule))
 #endif
 
+#ifdef SUPER_LOG
+#define log_rule_NL(rule) \
+   log_ruleNL((rule), pc)
+#else
+#define log_rule_NL(rule) \
+   log_ruleNL(LCURRENT, __func__, (rule))
+#endif
+
 void log_rule2(const char *func, size_t line, const char *rule, Chunk *first, Chunk *second);
 
 
@@ -46,4 +49,6 @@ void log_rule3(log_sev_t sev, const char *func, const char *rule);
 
 void log_rule4(const char *rule, Chunk *first);
 
+void log_ruleNL(const char *rule, Chunk *pc);
+
 #endif /* LOG_RULES_H_INCLUDED */
