@@ -38,7 +38,7 @@ static void add_parens_between(Chunk *first, Chunk *last);
 static void check_bool_parens(Chunk *popen, Chunk *pclose, int nest);
 
 
-void do_parens(void)
+void do_parens()
 {
    constexpr static auto LCURRENT = LPARADD;
 
@@ -50,18 +50,17 @@ void do_parens(void)
    {
       Chunk *pc = Chunk::GetHead();
 
-      while (  (pc = pc->GetNextNcNnl()) != nullptr
-            && pc->IsNotNullChunk())
+      while ((pc = pc->GetNextNcNnl())->IsNotNullChunk())
       {
-         if (  pc->type != CT_SPAREN_OPEN
-            || (  get_chunk_parent_type(pc) != CT_IF
-               && get_chunk_parent_type(pc) != CT_ELSEIF
-               && get_chunk_parent_type(pc) != CT_SWITCH))
+         if (  pc->IsNot(CT_SPAREN_OPEN)
+            || (  pc->GetParentType() != CT_IF
+               && pc->GetParentType() != CT_ELSEIF
+               && pc->GetParentType() != CT_SWITCH))
          {
             continue;
          }
          // Grab the close sparen
-         Chunk *pclose = pc->GetNextType(CT_SPAREN_CLOSE, pc->level, E_Scope::PREPROC);
+         Chunk *pclose = pc->GetNextType(CT_SPAREN_CLOSE, pc->GetLevel(), E_Scope::PREPROC);
 
          if (pclose->IsNotNullChunk())
          {
@@ -73,7 +72,7 @@ void do_parens(void)
 } // do_parens
 
 
-void do_parens_assign(void)                         // Issue #3316
+void do_parens_assign()                         // Issue #3316
 {
    constexpr static auto LCURRENT = LPARADD;
 
@@ -85,53 +84,52 @@ void do_parens_assign(void)                         // Issue #3316
    {
       Chunk *pc = Chunk::GetHead();
 
-      while (  (pc = pc->GetNextNcNnl()) != nullptr
-            && pc->IsNotNullChunk())
+      while ((pc = pc->GetNextNcNnl())->IsNotNullChunk())
       {
-         if (chunk_is_token(pc, CT_ASSIGN))
+         if (pc->Is(CT_ASSIGN))
          {
-            LOG_FMT(LPARADD, "%s(%d): orig_line is %zu, text is '%s', level is %zu\n",
-                    __func__, __LINE__, pc->orig_line, pc->Text(), pc->level);
+            LOG_FMT(LPARADD, "%s(%d): orig line is %zu, text is '%s', level is %zu\n",
+                    __func__, __LINE__, pc->GetOrigLine(), pc->Text(), pc->GetLevel());
             // look before for a open sparen
-            size_t check_level = pc->level;
+            size_t check_level = pc->GetLevel();
             Chunk  *p          = pc->GetPrevNc(E_Scope::PREPROC);
 
             while (p->IsNotNullChunk())
             {
-               LOG_FMT(LPARADD, "%s(%d): orig_line is %zu, text is '%s', level is %zu, type is %s\n",
-                       __func__, __LINE__, p->orig_line, p->Text(), p->level, get_token_name(p->type));
+               LOG_FMT(LPARADD, "%s(%d): orig line is %zu, text is '%s', level is %zu, type is %s\n",
+                       __func__, __LINE__, p->GetOrigLine(), p->Text(), p->GetLevel(), get_token_name(p->GetType()));
 
-               //log_pcf_flags(LPARADD, p->flags);
-               if (p->flags.test(PCF_STMT_START))
+               //log_pcf_flags(LPARADD, p->GetFlags());
+               if (p->TestFlags(PCF_STMT_START))
                {
                   break;
                }
 
-               if (chunk_is_token(p, CT_PAREN_OPEN))
+               if (p->Is(CT_PAREN_OPEN))
                {
                   check_level--;
                }
 
-               if (chunk_is_token(p, CT_SPAREN_OPEN))
+               if (p->Is(CT_SPAREN_OPEN))
                {
                   break;
                }
                p = p->GetPrevNc(E_Scope::PREPROC);
 
-               if (p->level < check_level - 1)
+               if (p->GetLevel() < check_level - 1)
                {
                   break;
                }
             }
-            LOG_FMT(LPARADD, "%s(%d): orig_line is %zu, text is '%s', level is %zu, type is %s\n",
-                    __func__, __LINE__, p->orig_line, p->Text(), p->level, get_token_name(p->type));
+            LOG_FMT(LPARADD, "%s(%d): orig line is %zu, text is '%s', level is %zu, type is %s\n",
+                    __func__, __LINE__, p->GetOrigLine(), p->Text(), p->GetLevel(), get_token_name(p->GetType()));
 
-            if (get_chunk_parent_type(p) == CT_WHILE)
+            if (p->GetParentType() == CT_WHILE)
             {
                continue;
             }
             // Grab the semicolon
-            Chunk *semicolon = pc->GetNextType(CT_SEMICOLON, pc->level, E_Scope::PREPROC);
+            Chunk *semicolon = pc->GetNextType(CT_SEMICOLON, pc->GetLevel(), E_Scope::PREPROC);
 
             if (semicolon->IsNotNullChunk())
             {
@@ -144,7 +142,7 @@ void do_parens_assign(void)                         // Issue #3316
 } // do_parens_assign
 
 
-void do_parens_return(void)                         // Issue #3316
+void do_parens_return()                         // Issue #3316
 {
    constexpr static auto LCURRENT = LPARADD;
 
@@ -156,53 +154,52 @@ void do_parens_return(void)                         // Issue #3316
    {
       Chunk *pc = Chunk::GetHead();
 
-      while (  (pc = pc->GetNextNcNnl()) != nullptr
-            && pc->IsNotNullChunk())
+      while ((pc = pc->GetNextNcNnl())->IsNotNullChunk())
       {
-         if (chunk_is_token(pc, CT_RETURN))
+         if (pc->Is(CT_RETURN))
          {
-            LOG_FMT(LPARADD, "%s(%d): orig_line is %zu, text is '%s', level is %zu\n",
-                    __func__, __LINE__, pc->orig_line, pc->Text(), pc->level);
+            LOG_FMT(LPARADD, "%s(%d): orig line is %zu, text is '%s', level is %zu\n",
+                    __func__, __LINE__, pc->GetOrigLine(), pc->Text(), pc->GetLevel());
             // look before for a open sparen
-            size_t check_level = pc->level;
+            size_t check_level = pc->GetLevel();
             Chunk  *p          = pc->GetPrevNc(E_Scope::PREPROC);
 
             while (p->IsNotNullChunk())
             {
-               LOG_FMT(LPARADD, "%s(%d): orig_line is %zu, text is '%s', level is %zu, type is %s\n",
-                       __func__, __LINE__, p->orig_line, p->Text(), p->level, get_token_name(p->type));
+               LOG_FMT(LPARADD, "%s(%d): orig line is %zu, text is '%s', level is %zu, type is %s\n",
+                       __func__, __LINE__, p->GetOrigLine(), p->Text(), p->GetLevel(), get_token_name(p->GetType()));
 
-               //log_pcf_flags(LPARADD, p->flags);
-               if (p->flags.test(PCF_STMT_START))
+               //log_pcf_flags(LPARADD, p->GetFlags());
+               if (p->TestFlags(PCF_STMT_START))
                {
                   break;
                }
 
-               if (chunk_is_token(p, CT_PAREN_OPEN))
+               if (p->Is(CT_PAREN_OPEN))
                {
                   check_level--;
                }
 
-               if (chunk_is_token(p, CT_SPAREN_OPEN))
+               if (p->Is(CT_SPAREN_OPEN))
                {
                   break;
                }
                p = p->GetPrevNc(E_Scope::PREPROC);
 
-               if (p->level < check_level - 1)
+               if (p->GetLevel() < check_level - 1)
                {
                   break;
                }
             }
-            LOG_FMT(LPARADD, "%s(%d): orig_line is %zu, text is '%s', level is %zu, type is %s\n",
-                    __func__, __LINE__, p->orig_line, p->Text(), p->level, get_token_name(p->type));
+            LOG_FMT(LPARADD, "%s(%d): orig line is %zu, text is '%s', level is %zu, type is %s\n",
+                    __func__, __LINE__, p->GetOrigLine(), p->Text(), p->GetLevel(), get_token_name(p->GetType()));
 
-            if (get_chunk_parent_type(p) == CT_WHILE)
+            if (p->GetParentType() == CT_WHILE)
             {
                continue;
             }
             // Grab the semicolon
-            Chunk *semicolon = pc->GetNextType(CT_SEMICOLON, pc->level, E_Scope::PREPROC);
+            Chunk *semicolon = pc->GetNextType(CT_SEMICOLON, pc->GetLevel(), E_Scope::PREPROC);
 
             if (semicolon->IsNotNullChunk())
             {
@@ -220,9 +217,9 @@ static void add_parens_between(Chunk *first, Chunk *last)
    LOG_FUNC_ENTRY();
 
    LOG_FMT(LPARADD, "%s(%d): line %zu, between '%s' [lvl is %zu] and '%s' [lvl is %zu]\n",
-           __func__, __LINE__, first->orig_line,
-           first->Text(), first->level,
-           last->Text(), last->level);
+           __func__, __LINE__, first->GetOrigLine(),
+           first->Text(), first->GetLevel(),
+           last->Text(), last->GetLevel());
 
    // Don't do anything if we have a bad sequence, ie "&& )"
    Chunk *first_n = first->GetNextNcNnl();
@@ -233,38 +230,38 @@ static void add_parens_between(Chunk *first, Chunk *last)
    }
    Chunk pc;
 
-   set_chunk_type(&pc, CT_PAREN_OPEN);
-   pc.orig_line   = first_n->orig_line;
-   pc.orig_col    = first_n->orig_col;
-   pc.str         = "(";
-   pc.flags       = first_n->flags & PCF_COPY_FLAGS;
-   pc.level       = first_n->level;
-   pc.pp_level    = first_n->pp_level;
-   pc.brace_level = first_n->brace_level;
+   pc.SetType(CT_PAREN_OPEN);
+   pc.SetOrigLine(first_n->GetOrigLine());
+   pc.SetOrigCol(first_n->GetOrigCol());
+   pc.Str() = "(";
+   pc.SetFlags(first_n->GetFlags() & PCF_COPY_FLAGS);
+   pc.SetLevel(first_n->GetLevel());
+   pc.SetPpLevel(first_n->GetPpLevel());
+   pc.SetBraceLevel(first_n->GetBraceLevel());
 
-   chunk_add_before(&pc, first_n);
+   pc.CopyAndAddBefore(first_n);
 
    Chunk *last_p = last->GetPrevNcNnl(E_Scope::PREPROC);
 
-   set_chunk_type(&pc, CT_PAREN_CLOSE);
-   pc.orig_line   = last_p->orig_line;
-   pc.orig_col    = last_p->orig_col;
-   pc.str         = ")";
-   pc.flags       = last_p->flags & PCF_COPY_FLAGS;
-   pc.level       = last_p->level;
-   pc.pp_level    = last_p->pp_level;
-   pc.brace_level = last_p->brace_level;
+   pc.SetType(CT_PAREN_CLOSE);
+   pc.SetOrigLine(last_p->GetOrigLine());
+   pc.SetOrigCol(last_p->GetOrigCol());
+   pc.Str() = ")";
+   pc.SetFlags(last_p->GetFlags() & PCF_COPY_FLAGS);
+   pc.SetLevel(last_p->GetLevel());
+   pc.SetPpLevel(last_p->GetPpLevel());
+   pc.SetBraceLevel(last_p->GetBraceLevel());
 
-   chunk_add_after(&pc, last_p);
+   pc.CopyAndAddAfter(last_p);
 
    for (Chunk *tmp = first_n;
         tmp != last_p;
         tmp = tmp->GetNextNcNnl())
    {
-      tmp->level++;
+      tmp->SetLevel(tmp->GetLevel() + 1);
    }
 
-   last_p->level++;
+   last_p->SetLevel(last_p->GetLevel() + 1);
 } // add_parens_between
 
 
@@ -275,34 +272,33 @@ static void check_bool_parens(Chunk *popen, Chunk *pclose, int nest)
    Chunk *ref        = popen;
    bool  hit_compare = false;
 
-   LOG_FMT(LPARADD, "%s(%d): nest is %d, popen on line %zu, orig_col is %zu, pclose on line %zu, orig_col is %zu, level is %zu\n",
+   LOG_FMT(LPARADD, "%s(%d): nest is %d, popen on line %zu, orig col is %zu, pclose on line %zu, orig col is %zu, level is %zu\n",
            __func__, __LINE__, nest,
-           popen->orig_line, popen->orig_col,
-           pclose->orig_line, pclose->orig_col,
-           popen->level);
+           popen->GetOrigLine(), popen->GetOrigCol(),
+           pclose->GetOrigLine(), pclose->GetOrigCol(),
+           popen->GetLevel());
 
    Chunk *pc = popen;
 
-   while (  (pc = pc->GetNextNcNnl()) != nullptr
-         && pc->IsNotNullChunk()
+   while (  (pc = pc->GetNextNcNnl())->IsNotNullChunk()
          && pc != pclose)
    {
-      if (pc->flags.test(PCF_IN_PREPROC))
+      if (pc->TestFlags(PCF_IN_PREPROC))
       {
          LOG_FMT(LPARADD2, " -- bail on PP %s [%s] at line %zu col %zu, level %zu\n",
-                 get_token_name(pc->type),
-                 pc->Text(), pc->orig_line, pc->orig_col, pc->level);
+                 get_token_name(pc->GetType()),
+                 pc->Text(), pc->GetOrigLine(), pc->GetOrigCol(), pc->GetLevel());
          return;
       }
 
-      if (  chunk_is_token(pc, CT_BOOL)
-         || chunk_is_token(pc, CT_QUESTION)
-         || chunk_is_token(pc, CT_COND_COLON)
-         || chunk_is_token(pc, CT_COMMA))
+      if (  pc->Is(CT_BOOL)
+         || pc->Is(CT_QUESTION)
+         || pc->Is(CT_COND_COLON)
+         || pc->Is(CT_COMMA))
       {
          LOG_FMT(LPARADD2, " -- %s [%s] at line %zu col %zu, level %zu\n",
-                 get_token_name(pc->type),
-                 pc->Text(), pc->orig_line, pc->orig_col, pc->level);
+                 get_token_name(pc->GetType()),
+                 pc->Text(), pc->GetOrigLine(), pc->GetOrigCol(), pc->GetLevel());
 
          if (hit_compare)
          {
@@ -315,28 +311,28 @@ static void check_bool_parens(Chunk *popen, Chunk *pclose, int nest)
          }
          ref = pc;
       }
-      else if (chunk_is_token(pc, CT_COMPARE))
+      else if (pc->Is(CT_COMPARE))
       {
-         LOG_FMT(LPARADD2, " -- compare '%s' at line %zu, orig_col is %zu, level is %zu\n",
-                 pc->Text(), pc->orig_line, pc->orig_col, pc->level);
+         LOG_FMT(LPARADD2, " -- compare '%s' at line %zu, orig col is %zu, level is %zu\n",
+                 pc->Text(), pc->GetOrigLine(), pc->GetOrigCol(), pc->GetLevel());
          hit_compare = true;
       }
-      else if (chunk_is_paren_open(pc))
+      else if (pc->IsParenOpen())
       {
-         Chunk *next = chunk_skip_to_match(pc);
+         Chunk *next = pc->GetClosingParen();
 
-         if (next != nullptr)
+         if (next->IsNotNullChunk())
          {
             check_bool_parens(pc, next, nest + 1);
             pc = next;
          }
       }
-      else if (  chunk_is_token(pc, CT_BRACE_OPEN)
-              || chunk_is_token(pc, CT_SQUARE_OPEN)
-              || chunk_is_token(pc, CT_ANGLE_OPEN))
+      else if (  pc->Is(CT_BRACE_OPEN)
+              || pc->Is(CT_SQUARE_OPEN)
+              || pc->Is(CT_ANGLE_OPEN))
       {
          // Skip [], {}, and <>
-         pc = chunk_skip_to_match(pc);
+         pc = pc->GetClosingParen();
       }
    }
 
