@@ -145,9 +145,9 @@ enum E_Token
    CT_CLASS_COLON,         // colon after a class def
    CT_CONSTR_COLON,        // colon after a constructor
    CT_D_ARRAY_COLON,       // D named array initializer colon
-   CT_COND_COLON,          // conditional colon in  'b ? t : f'
+   CT_COND_COLON,          // conditional colon in 'b ? t : f'
    CT_WHERE_COLON,         // C# where-constraint colon (after the type)
-   CT_QUESTION,
+   CT_QUESTION,            // conditional question in 'b ? t : f'
    CT_COMMA,
 
    CT_ASM,
@@ -220,6 +220,9 @@ enum E_Token
    CT_TPAREN_OPEN,      // 'type' parenthetis used in function types
    CT_TPAREN_CLOSE,
 
+   CT_RPAREN_OPEN,      // functor                                    Issue #3914
+   CT_RPAREN_CLOSE,
+
    CT_BRACE_OPEN,       // {...}
    CT_BRACE_CLOSE,
 
@@ -309,6 +312,7 @@ enum E_Token
    CT_PP_ENDIF,         // #endif
    CT_PP_ASSERT,
    CT_PP_EMIT,
+   CT_PP_ENDASM,        // end of assembly code section
    CT_PP_ENDINPUT,
    CT_PP_ERROR,
    CT_PP_FILE,
