@@ -18,6 +18,7 @@
 #include "backup.h"
 #include "brace_cleanup.h"
 #include "braces.h"
+#include "change_int_types.h"
 #include "combine.h"
 #include "compat.h"
 #include "detect.h"
@@ -25,6 +26,9 @@
 #include "indent.h"
 #include "keywords.h"
 #include "lang_pawn.h"
+#include "language_names.h"
+#include "mark_functor.h"
+#include "mark_question_colon.h"
 #include "newlines.h"
 #include "output.h"
 #include "parameter_pack_cleanup.h"
@@ -32,6 +36,7 @@
 #include "parent_for_pp.h"
 #include "remove_duplicate_include.h"
 #include "remove_extra_returns.h"
+#include "rewrite_infinite_loops.h"
 #include "semicolons.h"
 #include "sorting.h"
 #include "space.h"
@@ -87,9 +92,6 @@ using namespace uncrustify;
 cp_data_t cpd;
 
 
-static size_t language_flags_from_name(const char *tag);
-
-
 /**
  * Find the language for the file extension
  * Defaults to C
@@ -97,7 +99,7 @@ static size_t language_flags_from_name(const char *tag);
  * @param filename   The name of the file
  * @return           LANG_xxx
  */
-static size_t language_flags_from_filename(const char *filename);
+//static size_t language_flags_from_filename(const char *filename);
 
 
 static bool read_stdin(file_mem &fm);
@@ -106,9 +108,6 @@ static bool read_stdin(file_mem &fm);
 static void uncrustify_start(const deque<int> &data);
 
 
-static bool ends_with(const char *filename, const char *tag, bool case_sensitive);
-
-
 /**
  * Does a source file.
  *
@@ -173,7 +172,7 @@ static int load_mem_file_config(const std::string &filename, file_mem &fm);
 
 
 //! print uncrustify version number and terminate
-static void version_exit(void);
+static void version_exit();
 
 
 const char *path_basename(const char *path)
@@ -300,7 +299,8 @@ void usage(const char *argv0)
            " -L SEV                : Set the log severity (see log_levels.h; note 'A' = 'all')\n"
            " -s                    : Show the log severity in the logs.\n"
            " --decode              : Decode remaining args (chunk flags) and exit.\n"
-           " --tracking_space FILE : Prepare tracking informations for debugging.\n"
+           " --tracking_space FILE : Prepare space tracking information for debugging.\n"
+           " --tracking_nl FILE    : Prepare newline tracking information for debugging.\n"
            "                         Cannot be used with the -o option'\n"
            "\n"
            "Usage Examples\n"
@@ -324,7 +324,7 @@ void usage(const char *argv0)
 } // usage
 
 
-static void version_exit(void)
+static void version_exit()
 {
    printf("%s\n", UNCRUSTIFY_VERSION);
    exit(EX_OK);
@@ -343,9 +343,8 @@ NODISCARD static int redir_stdout(const char *output_file)
       {
          LOG_FMT(LERR, "Unable to open %s for write: %s (%d)\n",
                  output_file, strerror(errno), errno);
-         cpd.error_count++;
          usage_error();
-         return(EX_IOERR);
+         exit(EX_IOERR);
       }
       LOG_FMT(LNOTE, "Redirecting output to %s\n", output_file);
    }
@@ -427,14 +426,14 @@ int main(int argc, char *argv[])
    // output.cpp, line 427: fprintf(pfile, "# Line              Tag                Parent...
    // and              430: ... fprintf(pfile, "%s# %3zu>%19.19s[%19.19s] ...
    // here                                                xx xx   xx xx
-   for (size_t token = 0; token < ARRAY_SIZE(token_names); token++)
+   for (const auto &token_name : token_names)
    {
-      const size_t name_length = strlen(token_names[token]);
+      const size_t name_length = strlen(token_name);
 
       if (name_length > max_name_length)
       {
          fprintf(stderr, "%s(%d): The token name '%s' is too long (%d)\n",
-                 __func__, __LINE__, token_names[token], static_cast<int>(name_length));
+                 __func__, __LINE__, token_name, static_cast<int>(name_length));
          fprintf(stderr, "%s(%d): the max token name length is %d\n",
                  __func__, __LINE__, max_name_length);
          log_flush(true);
@@ -443,7 +442,7 @@ int main(int argc, char *argv[])
    }
 
    // make sure we have token_names.h in sync with token_enum.h
-   assert(ARRAY_SIZE(token_names) == CT_TOKEN_COUNT_);
+   static_assert(ARRAY_SIZE(token_names) == CT_TOKEN_COUNT_, "");
 #endif // DEBUG
 
    Args arg(argc, argv);
@@ -507,7 +506,7 @@ int main(int argc, char *argv[])
 
       while ((p_arg = arg.Unused(idx)) != nullptr)
       {
-         log_pcf_flags(LSYS, static_cast<pcf_flag_e>(strtoul(p_arg, nullptr, 16)));
+         log_pcf_flags(LSYS, static_cast<E_PcfFlag>(strtoul(p_arg, nullptr, 16)));
       }
       return(EXIT_SUCCESS);
    }
@@ -558,12 +557,15 @@ int main(int argc, char *argv[])
       }
    }
    // Get the dump file name prefix
-   const char *dump_file;
+   const char *dump_file_T;
 
-   if (  ((dump_file = arg.Param("--dump-steps")) != nullptr)
-      || ((dump_file = arg.Param("-ds")) != nullptr))
+   if (  ((dump_file_T = arg.Param("--dump-steps")) != nullptr)
+      || ((dump_file_T = arg.Param("-ds")) != nullptr))
    {
-      LOG_FMT(LNOTE, "Will export formatting steps data to '%s_nnn.log' files\n", dump_file);
+      // and save it
+      // Issue #3976
+      set_dump_file_name(dump_file_T);
+      LOG_FMT(LNOTE, "Will export formatting steps data to '%s_nnn.log' files\n", dump_file_name);
    }
 
    // Enable log severities
@@ -658,17 +660,42 @@ int main(int argc, char *argv[])
    const char *output_file = arg.Param("-o");
 
    // for debugging tracking
-   cpd.html_file = arg.Param("--tracking_space");
+   const char *html_file = nullptr;
+   html_file = arg.Param("--tracking_space");
 
+   if (html_file != nullptr)
+   {
+      cpd.html_type = tracking_type_e::TT_SPACE;
+      cpd.html_file = html_file;
+      html_file     = arg.Param("--tracking_nl");
+      bool try_it = html_file != nullptr;
+
+      if (try_it)
+      {
+         usage_error("Cannot specify both --tracking_space and --tracking_nl.");
+         return(EX_NOUSER);
+      }
+   }
+   else
+   {
+      html_file = arg.Param("--tracking_nl");
+      bool try_it = html_file != nullptr;
+
+      if (try_it)
+      {
+         cpd.html_type = tracking_type_e::TT_NEWLINE;
+         cpd.html_file = html_file;
+      }
+   }
    LOG_FMT(LDATA, "%s\n", UNCRUSTIFY_VERSION);
    LOG_FMT(LDATA, "config_file = %s\n", cfg_file.c_str());
-   LOG_FMT(LDATA, "output_file = %s\n", (output_file != NULL) ? output_file : "null");
-   LOG_FMT(LDATA, "source_file = %s\n", (source_file != NULL) ? source_file : "null");
-   LOG_FMT(LDATA, "source_list = %s\n", (source_list != NULL) ? source_list : "null");
-   LOG_FMT(LDATA, "tracking    = %s\n", (cpd.html_file != NULL) ? cpd.html_file : "null");
-   LOG_FMT(LDATA, "prefix      = %s\n", (prefix != NULL) ? prefix : "null");
-   LOG_FMT(LDATA, "suffix      = %s\n", (suffix != NULL) ? suffix : "null");
-   LOG_FMT(LDATA, "assume      = %s\n", (assume != NULL) ? assume : "null");
+   LOG_FMT(LDATA, "output_file = %s\n", (output_file != nullptr) ? output_file : "null");
+   LOG_FMT(LDATA, "source_file = %s\n", (source_file != nullptr) ? source_file : "null");
+   LOG_FMT(LDATA, "source_list = %s\n", (source_list != nullptr) ? source_list : "null");
+   LOG_FMT(LDATA, "tracking    = %s\n", (cpd.html_file != nullptr) ? cpd.html_file : "null");
+   LOG_FMT(LDATA, "prefix      = %s\n", (prefix != nullptr) ? prefix : "null");
+   LOG_FMT(LDATA, "suffix      = %s\n", (suffix != nullptr) ? suffix : "null");
+   LOG_FMT(LDATA, "assume      = %s\n", (assume != nullptr) ? assume : "null");
    LOG_FMT(LDATA, "replace     = %s\n", replace ? "true" : "false");
    LOG_FMT(LDATA, "no_backup   = %s\n", no_backup ? "true" : "false");
    LOG_FMT(LDATA, "detect      = %s\n", detect ? "true" : "false");
@@ -740,11 +767,11 @@ int main(int argc, char *argv[])
       if (options::nl_max() > 0)
       {
          // test if one/some option(s) is/are not too big for that
-         log_rule_B("nl_func_var_def_blk");
+         log_rule_B("nl_var_def_blk_end_func_top");
 
-         if (options::nl_func_var_def_blk() >= options::nl_max())
+         if (options::nl_var_def_blk_end_func_top() >= options::nl_max())
          {
-            fprintf(stderr, "The option 'nl_func_var_def_blk' is too big against the option 'nl_max'\n");
+            fprintf(stderr, "The option 'nl_var_def_blk_end_func_top' is too big against the option 'nl_max'\n");
             log_flush(true);
             exit(EX_CONFIG);
          }
@@ -860,8 +887,7 @@ int main(int argc, char *argv[])
       if (load_mem_file(source_file, fm) < 0)
       {
          LOG_FMT(LERR, "Failed to load (%s)\n", source_file);
-         cpd.error_count++;
-         return(EXIT_FAILURE);
+         exit(EX_IOERR);
       }
       uncrustify_start(fm.data);
       detect_options();
@@ -967,8 +993,7 @@ int main(int argc, char *argv[])
       if (!read_stdin(fm))
       {
          LOG_FMT(LERR, "Failed to read stdin\n");
-         cpd.error_count++;
-         return(100);
+         exit(EX_IOERR);
       }
       cpd.filename = "stdin";
 
@@ -979,12 +1004,12 @@ int main(int argc, char *argv[])
 
       // Issue #3427
       init_keywords_for_language();
-      uncrustify_file(fm, stdout, parsed_file, dump_file);
+      uncrustify_file(fm, stdout, parsed_file, dump_file_name);
    }
    else if (source_file != nullptr)
    {
       // Doing a single file
-      do_source_file(source_file, output_file, parsed_file, dump_file, no_backup, keep_mtime);
+      do_source_file(source_file, output_file, parsed_file, dump_file_name, no_backup, keep_mtime);
    }
    else
    {
@@ -995,7 +1020,7 @@ int main(int argc, char *argv[])
          exit(EX_CONFIG);
       }
 
-      if (dump_file != nullptr)
+      if (dump_file_name[0] != char(0))                // Issue #3976
       {
          fprintf(stderr, "FAIL: -ds/--dump-steps option must be used with the -f option\n");
          log_flush(true);
@@ -1030,11 +1055,6 @@ int main(int argc, char *argv[])
    }
    clear_keyword_file();
 
-   if (cpd.error_count != 0)
-   {
-      return(EXIT_FAILURE);
-   }
-
    if (  cpd.do_check
       && cpd.check_fail_cnt != 0)
    {
@@ -1055,8 +1075,7 @@ static void process_source_list(const char *source_list,
    {
       LOG_FMT(LERR, "%s: fopen(%s) failed: %s (%d)\n",
               __func__, source_list, strerror(errno), errno);
-      cpd.error_count++;
-      return;
+      exit(EX_IOERR);
    }
    char linebuf[256];
    int  line = 0;
@@ -1172,8 +1191,7 @@ static void make_folders(const string &filename)
             {
                LOG_FMT(LERR, "%s: Unable to create %s: %s (%d)\n",
                        __func__, outname, strerror(errno), errno);
-               cpd.error_count++;
-               return;
+               exit(EX_IOERR);
             }
          }
          outname[idx] = PATH_SEP; // reconstruct full path to search for next subpath
@@ -1230,12 +1248,12 @@ static int load_mem_file(const char *filename, file_mem &fm)
       {
          LOG_FMT(LERR, "%s: fread(%s) failed: %s (%d)\n",
                  __func__, filename, strerror(errno), errno);
-         cpd.error_count++;
+         exit(EX_IOERR);
       }
       else if (!decode_unicode(fm.raw, fm.data, fm.enc, fm.bom))
       {
          LOG_FMT(LERR, "%s: failed to decode the file '%s'\n", __func__, filename);
-         cpd.error_count++;
+         exit(EX_IOERR);
       }
       else
       {
@@ -1271,7 +1289,7 @@ static int load_mem_file_config(const std::string &filename, file_mem &fm)
       if (retval < 0)
       {
          LOG_FMT(LERR, "Failed to load (%s) or (%s)\n", buf, filename.c_str());
-         cpd.error_count++;
+         exit(EX_IOERR);
       }
    }
    return(retval);
@@ -1500,11 +1518,10 @@ static void do_source_file(const char *filename_in,
    if (load_mem_file(filename_in, fm) < 0)
    {
       LOG_FMT(LERR, "Failed to load (%s)\n", filename_in);
-      cpd.error_count++;
-      return;
+      exit(EX_IOERR);
    }
-   LOG_FMT(LSYS, "%s(%d): Parsing: %s as language %s\n",
-           __func__, __LINE__, filename_in, language_name_from_flags(cpd.lang_flags));
+   LOG_FMT(LSYS, "%s: Parsing: %s as language %s\n",
+           __func__, filename_in, language_name_from_flags(cpd.lang_flags));
 
    // check keyword sort
    assert(keywords_are_sorted());
@@ -1559,8 +1576,7 @@ static void do_source_file(const char *filename_in,
                {
                   LOG_FMT(LERR, "%s: Failed to create backup file for %s\n",
                           __func__, filename_in);
-                  cpd.error_count++;
-                  return;
+                  exit(EX_IOERR);
                }
                need_backup = true;
             }
@@ -1573,8 +1589,7 @@ static void do_source_file(const char *filename_in,
          {
             LOG_FMT(LERR, "%s: Unable to create %s: %s (%d)\n",
                     __func__, filename_tmp.c_str(), strerror(errno), errno);
-            cpd.error_count++;
-            return;
+            exit(EX_IOERR);
          }
          did_open = true;
          //LOG_FMT(LSYS, "Output file %s\n", filename_out);
@@ -1583,9 +1598,9 @@ static void do_source_file(const char *filename_in,
 
    if (cpd.if_changed)
    {
-      for (deque<UINT8>::const_iterator i = cpd.bout->begin(), end = cpd.bout->end(); i != end; ++i)
+      for (UINT8 i : *cpd.bout)
       {
-         fputc(*i, pfout);
+         fputc(i, pfout);
       }
 
       uncrustify_end();
@@ -1629,7 +1644,7 @@ static void do_source_file(const char *filename_in,
             {
                LOG_FMT(LERR, "%s: Unable to rename '%s' to '%s'\n",
                        __func__, filename_tmp.c_str(), filename_out);
-               cpd.error_count++;
+               exit(EX_IOERR);
             }
          }
       }
@@ -1664,23 +1679,23 @@ static void add_file_footer()
 
    // Back up if the file ends with a newline
    if (  pc->IsNotNullChunk()
-      && chunk_is_newline(pc))
+      && pc->IsNewline())
    {
       pc = pc->GetPrev();
    }
 
    if (  pc->IsNotNullChunk()
       && (  !pc->IsComment()
-         || !chunk_is_newline(pc->GetPrev())))
+         || !pc->GetPrev()->IsNewline()))
    {
       pc = Chunk::GetTail();
 
-      if (!chunk_is_newline(pc))
+      if (!pc->IsNewline())
       {
          LOG_FMT(LSYS, "Adding a newline at the end of the file\n");
          newline_add_after(pc);
       }
-      tokenize(cpd.file_ftr.data, nullptr);
+      tokenize(cpd.file_ftr.data, Chunk::NullChunkPtr);
    }
 }
 
@@ -1694,13 +1709,13 @@ static void add_func_header(E_Token type, file_mem &fm)
 
    for (pc = Chunk::GetHead(); pc->IsNotNullChunk(); pc = pc->GetNextNcNnlNpp())
    {
-      if (pc->type != type)
+      if (pc->GetType() != type)
       {
          continue;
       }
       log_rule_B("cmt_insert_before_inlines");
 
-      if (  pc->flags.test(PCF_IN_CLASS)
+      if (  pc->TestFlags(PCF_IN_CLASS)
          && !options::cmt_insert_before_inlines())
       {
          continue;
@@ -1708,20 +1723,20 @@ static void add_func_header(E_Token type, file_mem &fm)
       // Check for one liners for classes. Declarations only. Walk down the chunks.
       ref = pc;
 
-      if (  chunk_is_token(ref, CT_CLASS)
-         && get_chunk_parent_type(ref) == CT_NONE
+      if (  ref->Is(CT_CLASS)
+         && ref->GetParentType() == CT_NONE
          && ref->GetNext())
       {
          ref = ref->GetNext();
 
-         if (  chunk_is_token(ref, CT_TYPE)
-            && get_chunk_parent_type(ref) == type
+         if (  ref->Is(CT_TYPE)
+            && ref->GetParentType() == type
             && ref->GetNext())
          {
             ref = ref->GetNext();
 
-            if (  chunk_is_token(ref, CT_SEMICOLON)
-               && ref->level == pc->level)
+            if (  ref->Is(CT_SEMICOLON)
+               && ref->GetLevel() == pc->GetLevel())
             {
                continue;
             }
@@ -1730,16 +1745,16 @@ static void add_func_header(E_Token type, file_mem &fm)
       // Check for one liners for functions. There'll be a closing brace w/o any newlines. Walk down the chunks.
       ref = pc;
 
-      if (  chunk_is_token(ref, CT_FUNC_DEF)
-         && get_chunk_parent_type(ref) == CT_NONE
+      if (  ref->Is(CT_FUNC_DEF)
+         && ref->GetParentType() == CT_NONE
          && ref->GetNext())
       {
          int found_brace = 0;                                 // Set if a close brace is found before a newline
 
-         while (  ref->type != CT_NEWLINE
+         while (  ref->IsNot(CT_NEWLINE)
                && (ref = ref->GetNext())) // TODO: is the assignment of ref wanted here?, better move it to the loop
          {
-            if (chunk_is_token(ref, CT_BRACE_CLOSE))
+            if (ref->Is(CT_BRACE_CLOSE))
             {
                found_brace = 1;
                break;
@@ -1763,27 +1778,27 @@ static void add_func_header(E_Token type, file_mem &fm)
             && ref->IsNotNullChunk())
       {
          // Bail if we change level or find an access specifier colon
-         if (  ref->level != pc->level
-            || chunk_is_token(ref, CT_ACCESS_COLON))
+         if (  ref->GetLevel() != pc->GetLevel()
+            || ref->Is(CT_ACCESS_COLON))
          {
             do_insert = true;
             break;
          }
 
          // If we hit an angle close, back up to the angle open
-         if (chunk_is_token(ref, CT_ANGLE_CLOSE))
+         if (ref->Is(CT_ANGLE_CLOSE))
          {
-            ref = ref->GetPrevType(CT_ANGLE_OPEN, ref->level, E_Scope::PREPROC);
+            ref = ref->GetPrevType(CT_ANGLE_OPEN, ref->GetLevel(), E_Scope::PREPROC);
             continue;
          }
 
          // Bail if we hit a preprocessor and cmt_insert_before_preproc is false
-         if (ref->flags.test(PCF_IN_PREPROC))
+         if (ref->TestFlags(PCF_IN_PREPROC))
          {
-            tmp = ref->GetPrevType(CT_PREPROC, ref->level);
+            tmp = ref->GetPrevType(CT_PREPROC, ref->GetLevel());
 
             if (  tmp->IsNotNullChunk()
-               && get_chunk_parent_type(tmp) == CT_PP_IF)
+               && tmp->GetParentType() == CT_PP_IF)
             {
                tmp = tmp->GetPrevNnl();
 
@@ -1799,15 +1814,15 @@ static void add_func_header(E_Token type, file_mem &fm)
 
          // Ignore 'right' comments
          if (  ref->IsComment()
-            && chunk_is_newline(ref->GetPrev()))
+            && ref->GetPrev()->IsNewline())
          {
             break;
          }
 
-         if (  ref->level == pc->level
-            && (  ref->flags.test(PCF_IN_PREPROC)
-               || chunk_is_token(ref, CT_SEMICOLON)
-               || chunk_is_token(ref, CT_BRACE_CLOSE)))
+         if (  ref->GetLevel() == pc->GetLevel()
+            && (  ref->TestFlags(PCF_IN_PREPROC)
+               || ref->Is(CT_SEMICOLON)
+               || ref->Is(CT_BRACE_CLOSE)))
          {
             do_insert = true;
             break;
@@ -1816,7 +1831,7 @@ static void add_func_header(E_Token type, file_mem &fm)
 
       if (  ref->IsNullChunk()
          && !Chunk::GetHead()->IsComment()
-         && get_chunk_parent_type(Chunk::GetHead()) == type)
+         && Chunk::GetHead()->GetParentType() == type)
       {
          /**
           * In addition to testing for preceding semicolons, closing braces, etc.,
@@ -1833,7 +1848,7 @@ static void add_func_header(E_Token type, file_mem &fm)
 
          for (tmp = ref->GetNext(); tmp != after; tmp = tmp->GetNext())
          {
-            tmp->level = after->level;
+            tmp->SetLevel(after->GetLevel());
          }
       }
    }
@@ -1849,7 +1864,7 @@ static void add_msg_header(E_Token type, file_mem &fm)
 
    for (pc = Chunk::GetHead(); pc->IsNotNullChunk(); pc = pc->GetNextNcNnlNpp())
    {
-      if (pc->type != type)
+      if (pc->GetType() != type)
       {
          continue;
       }
@@ -1861,31 +1876,30 @@ static void add_msg_header(E_Token type, file_mem &fm)
        */
       ref = pc;
 
-      while (  (ref = ref->GetPrev()) != nullptr
-            && ref->IsNotNullChunk())
+      while ((ref = ref->GetPrev())->IsNotNullChunk())
       {
          // ignore the CT_TYPE token that is the result type
-         if (  ref->level != pc->level
-            && (  chunk_is_token(ref, CT_TYPE)
-               || chunk_is_token(ref, CT_PTR_TYPE)))
+         if (  ref->GetLevel() != pc->GetLevel()
+            && (  ref->Is(CT_TYPE)
+               || ref->Is(CT_PTR_TYPE)))
          {
             continue;
          }
 
          // If we hit a parentheses around return type, back up to the open parentheses
-         if (chunk_is_token(ref, CT_PAREN_CLOSE))
+         if (ref->Is(CT_PAREN_CLOSE))
          {
-            ref = ref->GetPrevType(CT_PAREN_OPEN, ref->level, E_Scope::PREPROC);
+            ref = ref->GetPrevType(CT_PAREN_OPEN, ref->GetLevel(), E_Scope::PREPROC);
             continue;
          }
 
          // Bail if we hit a preprocessor and cmt_insert_before_preproc is false
-         if (ref->flags.test(PCF_IN_PREPROC))
+         if (ref->TestFlags(PCF_IN_PREPROC))
          {
-            tmp = ref->GetPrevType(CT_PREPROC, ref->level);
+            tmp = ref->GetPrevType(CT_PREPROC, ref->GetLevel());
 
             if (  tmp->IsNotNullChunk()
-               && get_chunk_parent_type(tmp) == CT_PP_IF)
+               && tmp->GetParentType() == CT_PP_IF)
             {
                tmp = tmp->GetPrevNnl();
 
@@ -1899,16 +1913,16 @@ static void add_msg_header(E_Token type, file_mem &fm)
             }
          }
 
-         if (  ref->level == pc->level
-            && (  ref->flags.test(PCF_IN_PREPROC)
-               || chunk_is_token(ref, CT_OC_SCOPE)))
+         if (  ref->GetLevel() == pc->GetLevel()
+            && (  ref->TestFlags(PCF_IN_PREPROC)
+               || ref->Is(CT_OC_SCOPE)))
          {
             ref = ref->GetPrev();
 
             if (ref->IsNotNullChunk())
             {
                // Ignore 'right' comments
-               if (  chunk_is_newline(ref)
+               if (  ref->IsNewline()
                   && ref->GetPrev()->IsComment())
                {
                   break;
@@ -1927,7 +1941,7 @@ static void add_msg_header(E_Token type, file_mem &fm)
 
          for (tmp = ref->GetNext(); tmp != after; tmp = tmp->GetNext())
          {
-            tmp->level = after->level;
+            tmp->SetLevel(after->GetLevel());
          }
       }
    }
@@ -1937,7 +1951,7 @@ static void add_msg_header(E_Token type, file_mem &fm)
 static void uncrustify_start(const deque<int> &data)
 {
    // Parse the text into chunks
-   tokenize(data, nullptr);
+   tokenize(data, Chunk::NullChunkPtr);
    PROT_THE_LINE
 
    cpd.unc_stage = unc_stage_e::HEADER;
@@ -1947,7 +1961,7 @@ static void uncrustify_start(const deque<int> &data)
    {
       Chunk *pc = Chunk::GetHead();
 
-      cpd.frag_cols = pc->orig_col;
+      cpd.frag_cols = pc->GetOrigCol();
    }
 
    // Add the file header
@@ -1983,8 +1997,11 @@ static void uncrustify_start(const deque<int> &data)
    {
       pawn_prescan();
    }
+   mark_question_colon();
+
    // Re-type chunks, combine chunks
    fix_symbols();
+
    tokenize_trailing_return_types();
 
    mark_comments();
@@ -1993,6 +2010,8 @@ static void uncrustify_start(const deque<int> &data)
    combine_labels();
 
    enum_cleanup();
+
+   mark_functor();
 } // uncrustify_start
 
 
@@ -2053,8 +2072,7 @@ void uncrustify_file(const file_mem &fm, FILE *pfout, const char *parsed_file,
                  cpd.filename.c_str(), count_line, count_column);
          LOG_FMT(LERR, "The file may be encoded in an unsupported Unicode format.\n");
          LOG_FMT(LERR, "Aborting.\n");
-         cpd.error_count++;
-         return;
+         exit(EX_IOERR);
       }
       count_column++;
 
@@ -2098,6 +2116,14 @@ void uncrustify_file(const file_mem &fm, FILE *pfout, const char *parsed_file,
          add_msg_header(CT_OC_MSG_DECL, cpd.oc_msg_hdr);
       }
       do_parent_for_pp();
+
+      // Rewrite infinite loops
+      log_rule_B("mod_infinite_loop");
+
+      if (options::mod_infinite_loop())
+      {
+         rewrite_infinite_loops();
+      }
       do_braces();  // Change virtual braces into real braces...
 
       // Scrub extra semicolons
@@ -2114,8 +2140,31 @@ void uncrustify_file(const file_mem &fm, FILE *pfout, const char *parsed_file,
       {
          remove_extra_returns();
       }
+      // Add or remove redundant 'int' keyword of integer types
+      log_rule_B("mod_int_short");
+      log_rule_B("mod_short_int");
+      log_rule_B("mod_int_long");
+      log_rule_B("mod_long_int");
+      log_rule_B("mod_int_signed");
+      log_rule_B("mod_signed_int");
+      log_rule_B("mod_int_unsigned");
+      log_rule_B("mod_unsigned_int");
+
+      if (  (  language_is_set(LANG_C)
+            || language_is_set(LANG_CPP))
+         && (  options::mod_int_short() != IARF_IGNORE
+            || options::mod_short_int() != IARF_IGNORE
+            || options::mod_int_long() != IARF_IGNORE
+            || options::mod_long_int() != IARF_IGNORE
+            || options::mod_int_signed() != IARF_IGNORE
+            || options::mod_signed_int() != IARF_IGNORE
+            || options::mod_int_unsigned() != IARF_IGNORE
+            || options::mod_unsigned_int() != IARF_IGNORE))
+      {
+         change_int_types();
+      }
       // Remove duplicate include
-      log_rule_B("mod_duplicate_include");
+      log_rule_B("mod_remove_duplicate_include");
 
       if (options::mod_remove_duplicate_include())
       {
@@ -2413,7 +2462,7 @@ void uncrustify_file(const file_mem &fm, FILE *pfout, const char *parsed_file,
       {
          LOG_FMT(LERR, "%s: Failed to open '%s' for write: %s (%d)\n",
                  __func__, parsed_file, strerror(errno), errno);
-         cpd.error_count++;
+         exit(EX_IOERR);
       }
    }
 
@@ -2439,7 +2488,7 @@ void uncrustify_end()
 
    while ((pc = Chunk::GetHead())->IsNotNullChunk())
    {
-      chunk_del(pc);
+      Chunk::Delete(pc);
    }
 
    if (cpd.bout)
@@ -2487,222 +2536,3 @@ E_Token find_token_name(const char *text)
    }
    return(CT_NONE);
 }
-
-
-static bool ends_with(const char *filename, const char *tag, bool case_sensitive = true)
-{
-   int len1 = strlen(filename);
-   int len2 = strlen(tag);
-
-   return(  len2 <= len1
-         && (  (  case_sensitive
-               && (strcmp(&filename[len1 - len2], tag) == 0))
-            || (  !case_sensitive
-               && (strcasecmp(&filename[len1 - len2], tag) == 0))));
-}
-
-
-struct lang_name_t
-{
-   const char *name;
-   size_t     lang;
-};
-
-static lang_name_t language_names[] =
-{
-   { "C",        LANG_C                       },      // 0x0001
-   { "CPP",      LANG_CPP                     },      // 0x0002
-   { "D",        LANG_D                       },      // 0x0004
-   { "CS",       LANG_CS                      },      // 0x0008
-   { "JAVA",     LANG_JAVA                    },      // 0x0010
-   { "OC",       LANG_OC                      },      // 0x0020
-   { "VALA",     LANG_VALA                    },      // 0x0040
-   { "PAWN",     LANG_PAWN                    },      // 0x0080
-   { "ECMA",     LANG_ECMA                    },      // 0x0100
-   { "OC+",      LANG_OC | LANG_CPP           },      // 0x0020 + 0x0002
-   { "CS+",      LANG_CS | LANG_CPP           },      // 0x0008 + 0x0002
-   { "C-Header", LANG_C | LANG_CPP | FLAG_HDR },      // 0x0001 + 0x0002 + 0x2000 = 0x2022
-};
-
-
-static size_t language_flags_from_name(const char *name)
-{
-   for (const auto &language : language_names)
-   {
-      if (strcasecmp(name, language.name) == 0)
-      {
-         return(language.lang);
-      }
-   }
-
-   return(0);
-}
-
-
-const char *language_name_from_flags(size_t lang)
-{
-   // Check for an exact match first
-   for (auto &language_name : language_names)
-   {
-      if (language_name.lang == lang)
-      {
-         return(language_name.name);
-      }
-   }
-
-   // Check for the first set language bit
-   for (auto &language_name : language_names)
-   {
-      if ((language_name.lang & lang) != 0)
-      {
-         return(language_name.name);
-      }
-   }
-
-   return("???");
-}
-
-
-//! type to map a programming language to a typically used filename extension
-struct lang_ext_t
-{
-   const char *ext;  //! filename extension typically used for ...
-   const char *name; //! a programming language
-};
-
-//! known filename extensions linked to the corresponding programming language
-struct lang_ext_t language_exts[] =
-{
-   { ".c",    "C"        },
-   { ".c++",  "CPP"      },
-   { ".cc",   "CPP"      },
-   { ".cp",   "CPP"      },
-   { ".cpp",  "CPP"      },
-   { ".cs",   "CS"       },
-   { ".cxx",  "CPP"      },
-   { ".d",    "D"        },
-   { ".di",   "D"        },
-   { ".es",   "ECMA"     },
-   { ".h",    "C-Header" },
-   { ".h++",  "CPP"      },
-   { ".hh",   "CPP"      },
-   { ".hp",   "CPP"      },
-   { ".hpp",  "CPP"      },
-   { ".hxx",  "CPP"      },
-   { ".inl",  "PAWN"     },
-   { ".java", "JAVA"     },
-   { ".js",   "ECMA"     },
-   { ".m",    "OC"       },
-   { ".mm",   "OC+"      },
-   { ".p",    "PAWN"     },
-   { ".pawn", "PAWN"     },
-   { ".sma",  "PAWN"     },
-   { ".sqc",  "C"        },  // embedded SQL
-   { ".sql",  "SQL"      },
-   { ".vala", "VALA"     },
-};
-
-
-const char *get_file_extension(int &idx)
-{
-   const char *val = nullptr;
-
-   if (idx < static_cast<int> ARRAY_SIZE(language_exts))
-   {
-      val = language_exts[idx].ext;
-   }
-   idx++;
-   return(val);
-}
-
-
-typedef std::map<string, string> extension_map_t;
-/**
- * maps a file extension to a language flag.
- *
- * @note The "." need to be included, as in ".c". The file extensions
- *       ARE case sensitive.
- */
-static extension_map_t g_ext_map;
-
-
-const char *extension_add(const char *ext_text, const char *lang_text)
-{
-   size_t lang_flags = language_flags_from_name(lang_text);
-
-   if (lang_flags)
-   {
-      const char *lang_name = language_name_from_flags(lang_flags);
-      g_ext_map[string(ext_text)] = lang_name;
-      return(lang_name);
-   }
-   return(nullptr);
-}
-
-
-void print_extensions(FILE *pfile)
-{
-   for (auto &language : language_names)
-   {
-      bool did_one = false;
-
-      for (auto &extension_val : g_ext_map)
-      {
-         if (strcmp(extension_val.second.c_str(), language.name) == 0)
-         {
-            if (!did_one)
-            {
-               fprintf(pfile, "file_ext %s", extension_val.second.c_str());
-               did_one = true;
-            }
-            fprintf(pfile, " %s", extension_val.first.c_str());
-         }
-      }
-
-      if (did_one)
-      {
-         fprintf(pfile, "\n");
-      }
-   }
-}
-
-
-// TODO: better use enum lang_t for source file language
-static size_t language_flags_from_filename(const char *filename)
-{
-   // check custom extensions first
-   for (const auto &extension_val : g_ext_map)
-   {
-      if (ends_with(filename, extension_val.first.c_str()))
-      {
-         return(language_flags_from_name(extension_val.second.c_str()));
-      }
-   }
-
-   for (auto &language : language_exts)
-   {
-      if (ends_with(filename, language.ext))
-      {
-         return(language_flags_from_name(language.name));
-      }
-   }
-
-   // check again without case sensitivity
-   for (auto &extension_val : g_ext_map)
-   {
-      if (ends_with(filename, extension_val.first.c_str(), false))
-      {
-         return(language_flags_from_name(extension_val.second.c_str()));
-      }
-   }
-
-   for (auto &language : language_exts)
-   {
-      if (ends_with(filename, language.ext, false))
-      {
-         return(language_flags_from_name(language.name));
-      }
-   }
-
-   return(LANG_C);
-} // language_flags_from_filename
