@@ -17,16 +17,13 @@
 #include "uncrustify_limits.h"
 
 #include <assert.h>
-#include <cstddef>      // do get the definition of size_t
+#include <cstddef>      // to get size_t
 
 #ifdef HAVE_UTIME_H
 #include <utime.h>
 #endif
 
 
-class ParseFrame;
-
-
 /**
  * abbreviations used:
  *   SS = star style
@@ -39,29 +36,17 @@ class ParseFrame;
 #define UNCRUSTIFY_OFF_TEXT    " *INDENT-OFF*"
 #define UNCRUSTIFY_ON_TEXT     " *INDENT-ON*"
 
-//! returns type (with removed reference) of a variable
-#define noref_decl_t(X)              std::remove_reference<decltype((X))>::type
-
-//! returns type (with removed const and reference) of a variable
-#define nocref_decl_t(X)             std::remove_const<noref_decl_t((X))>::type
-
-//! static casts Y to the type (with removed reference) of X
-#define s_cast_noref_decl_t(X, Y)    static_cast<nocref_decl_t(X)>(Y)
-
-//! performs abs on Y after static casting it to the type (with removed reference) of X
-#define cast_abs(X, Y)               s_cast_noref_decl_t(X, abs(Y))
-
 /**
  * @brief Macro to inform the compiler that a variable is intentionally
  * not in use.
  *
  * @param [in] variableName: The unused variable.
  */
-#define UNUSED(variableName)         ((void)variableName)
+#define UNUSED(variableName)    ((void)variableName)
 
 
 //! Brace stage enum used in brace_cleanup
-enum class brace_stage_e : unsigned int
+enum class E_BraceStage : unsigned int
 {
    NONE,
    PAREN1,      //! expected paren after if/catch (C++)/for/switch/synchronized/while
@@ -87,6 +72,13 @@ enum class char_encoding_e : unsigned int
    e_UTF16_BE   //! utf 16 bit wide, big endian
 };
 
+enum class tracking_type_e : unsigned int
+{
+   TT_NONE,
+   TT_SPACE,
+   TT_NEWLINE
+};
+
 
 class Chunk; //forward declaration
 
@@ -96,16 +88,16 @@ class Chunk; //forward declaration
  * indent of another chunk. This is needed, as that chunk may be aligned and
  * so the indent cannot be determined in the indent code.
  */
-struct indent_ptr_t
+struct IndentationData
 {
    Chunk *ref;
    int   delta;
 };
 
 
-struct align_ptr_t
+struct AlignmentData
 {
-   Chunk  *next;       //! nullptr or the chunk that should be under this one
+   Chunk  *next;       //! Chunk::NullChunkPtr or the chunk that should be under this one
    bool   right_align; //! AlignStack.m_right_align
    size_t star_style;  //! AlignStack.m_star_style
    size_t amp_style;   //! AlignStack.m_amp_style
@@ -123,30 +115,30 @@ struct align_ptr_t
 
 
 // for debugging purpose only
-typedef std::pair<size_t, char *>   Track_nr;         // track for "trackNumber" and "rule"
-typedef std::vector<Track_nr>       track_list;       // liste for many tracks
+typedef std::pair<size_t, char *>   TrackNumber;   // track for "trackNumber" and "rule"
+typedef std::vector<TrackNumber>    TrackList;     // list of tracks
 
-//! list of all programming languages Uncrustify supports
-enum lang_flag_e
-{
-   LANG_C    = 0x0001,
-   LANG_CPP  = 0x0002,
-   LANG_D    = 0x0004,
-   LANG_CS   = 0x0008,     //! C# (C-Sharp)
-   LANG_JAVA = 0x0010,
-   LANG_OC   = 0x0020,     //! Objective-C
-   LANG_VALA = 0x0040,
-   LANG_PAWN = 0x0080,
-   LANG_ECMA = 0x0100,     //! ECMA Script (JavaScript)
-
-   LANG_ALLC = 0x017f,     /** LANG_C    | LANG_CPP | LANG_D    | LANG_CS   |
-                            *  LANG_JAVA | LANG_OC  | LANG_VALA | LANG_ECMA   */
-   LANG_ALL  = 0x0fff,     //! applies to all languages
-
-   FLAG_HDR  = 0x2000,     /*<< Header file for C family languages */
-   FLAG_DIG  = 0x4000,     //! digraph/trigraph
-   FLAG_PP   = 0x8000,     //! only appears in a preprocessor
-};
+////! list of all programming languages Uncrustify supports
+//enum lang_flag_e
+//{
+//   LANG_C    = 0x0001,
+//   LANG_CPP  = 0x0002,
+//   LANG_D    = 0x0004,
+//   LANG_CS   = 0x0008,     //! C# (C-Sharp)
+//   LANG_JAVA = 0x0010,
+//   LANG_OC   = 0x0020,     //! Objective-C
+//   LANG_VALA = 0x0040,
+//   LANG_PAWN = 0x0080,
+//   LANG_ECMA = 0x0100,     //! ECMA Script (JavaScript)
+//
+//   LANG_ALLC = 0x017f,     /** LANG_C    | LANG_CPP | LANG_D    | LANG_CS   |
+//                            *  LANG_JAVA | LANG_OC  | LANG_VALA | LANG_ECMA   */
+//   LANG_ALL  = 0x0fff,     //! applies to all languages
+//
+//   FLAG_HDR  = 0x2000,     /*<< Header file for C family languages */
+//   FLAG_DIG  = 0x4000,     //! digraph/trigraph
+//   FLAG_PP   = 0x8000,     //! only appears in a preprocessor
+//};
 
 //! Pattern classes for special keywords
 enum class pattern_class_e : unsigned int
@@ -184,6 +176,7 @@ struct align_t
    size_t  col;
    E_Token type;
    size_t  len;      //! length of the token + space
+   Chunk   *ref;     // Issue #3786
 };
 
 //! holds information and data of a file
@@ -221,7 +214,6 @@ struct cp_data_t
    int               check_fail_cnt;       //! total failure count
    bool              if_changed;
 
-   UINT32            error_count;       //! counts how many errors occurred so far
    std::string       filename;
 
    file_mem          file_hdr;          // for cmt_insert_file_header
@@ -247,9 +239,9 @@ struct cp_data_t
 
    // stuff to auto-detect line endings
    UINT32            le_counts[uncrustify::line_end_styles];
-   unc_text          newline;
+   UncText           newline;
 
-   int               did_newline;       //! flag indicates if a newline was added or converted
+   bool              did_newline;       //! flag indicates if a newline was added or converted
    E_Token           in_preproc;
    int               preproc_ncnl_count;
    bool              output_trailspace;
@@ -272,12 +264,14 @@ struct cp_data_t
 
    const char        *phase_name;
    const char        *dumped_file;
-   const char        *html_file = nullptr; // for debugging purpose only
+   // for debugging purpose only
+   tracking_type_e   html_type  = tracking_type_e::TT_NONE;
+   const char        *html_file = nullptr;
 };
 
 extern cp_data_t cpd;  // TODO: can we avoid this external variable?
 
-const char *get_brace_stage_name(brace_stage_e brace_stage);
+const char *get_brace_stage_name(E_BraceStage brace_stage);
 
 const char *get_unc_stage_name(unc_stage_e unc_stage);
 
