@@ -23,14 +23,18 @@ using namespace uncrustify;
  * - fparen = function parenthesis
  */
 
-struct cw_entry
+struct SplitEntry
 {
    Chunk  *pc;
    size_t pri;
+
+   SplitEntry()
+      : pc(Chunk::NullChunkPtr)
+      , pri(0) {}
 };
 
 
-struct token_pri
+struct TokenPriority
 {
    E_Token tok;
    size_t  pri;
@@ -63,7 +67,7 @@ static size_t get_split_pri(E_Token tok);
  *  - ? :
  *  - function open paren not followed by close paren
  */
-static void try_split_here(cw_entry &ent, Chunk *pc);
+static void try_split_here(SplitEntry &ent, Chunk *pc);
 
 
 /**
@@ -82,7 +86,7 @@ static bool split_line(Chunk *pc);
  * Figures out where to split a function def/proto/call
  *
  * For function prototypes and definition. Also function calls where
- * level == brace_level:
+ * level == m_braceLevel:
  *   - find the open function parenthesis
  *     + if it doesn't have a newline right after it
  *       * see if all parameters will fit individually after the paren
@@ -129,10 +133,10 @@ static void split_for_stmt(Chunk *start);
 static inline bool is_past_width(Chunk *pc)
 {
    // allow char to sit at last column by subtracting 1
-   LOG_FMT(LSPLIT, "%s(%d): orig_line is %zu, orig_col is %zu, for %s\n",
-           __func__, __LINE__, pc->orig_line, pc->orig_col, pc->Text());
+   LOG_FMT(LSPLIT, "%s(%d): orig line is %zu, orig col is %zu, for %s\n",
+           __func__, __LINE__, pc->GetOrigLine(), pc->GetOrigCol(), pc->Text());
    log_rule_B("code_width");
-   return((pc->column + pc->Len() - 1) > options::code_width());
+   return((pc->GetColumn() + pc->Len() - 1) > options::code_width());
 }
 
 
@@ -141,34 +145,60 @@ static void split_before_chunk(Chunk *pc)
    LOG_FUNC_ENTRY();
    LOG_FMT(LSPLIT, "%s(%d): Text() '%s'\n", __func__, __LINE__, pc->Text());
 
-   if (  !chunk_is_newline(pc)
-      && !chunk_is_newline(pc->GetPrev()))
+   Chunk *prev = pc->GetPrev();
+
+   if (  !pc->IsNewline()
+      && !prev->IsNewline())
    {
       newline_add_before(pc);
+      // Mark chunk as continuation line, so indentation can be
+      // correctly set over multiple passes
+      pc->SetFlagBits(PCF_CONT_LINE);
+
+      // Mark open and close parens as continuation line chunks.
+      // This will prevent an additional level and frame to be
+      // added to the current frame stack (issue 3105).
+      if (  prev->Is(CT_PAREN_OPEN)
+         || prev->Is(CT_LPAREN_OPEN)
+         || prev->Is(CT_SPAREN_OPEN)
+         || prev->Is(CT_FPAREN_OPEN)
+         || prev->Is(CT_SQUARE_OPEN)
+         || prev->Is(CT_ANGLE_OPEN))
+      {
+         LOG_FMT(LSPLIT, "%s(%d): set PCF_LINE_CONT for prev text '%s', orig line is %zu, orig col is %zu\n",
+                 __func__, __LINE__, prev->Text(), prev->GetOrigLine(), prev->GetOrigCol());
+
+         prev->SetFlagBits(PCF_CONT_LINE);
+         Chunk *closing_paren = prev->GetClosingParen();
+
+         if (closing_paren->IsNotNullChunk())
+         {
+            closing_paren->SetFlagBits(PCF_CONT_LINE);
+         }
+      }
       // reindent needs to include the indent_continue value and was off by one
       log_rule_B("indent_columns");
       log_rule_B("indent_continue");
-      reindent_line(pc, pc->brace_level * options::indent_columns() +
+      reindent_line(pc, pc->GetBraceLevel() * options::indent_columns() +
                     abs(options::indent_continue()) + 1);
       cpd.changes++;
    }
-}
+} // split_before_chunk
 
 
-void do_code_width(void)
+void do_code_width()
 {
    LOG_FUNC_ENTRY();
    LOG_FMT(LSPLIT, "%s(%d)\n", __func__, __LINE__);
 
    for (Chunk *pc = Chunk::GetHead(); pc->IsNotNullChunk(); pc = pc->GetNext())
    {
-      if (  !chunk_is_newline(pc)
-         && !pc->IsComment()
-         && chunk_is_not_token(pc, CT_SPACE)
+      if (  !pc->IsCommentOrNewline()
+         && pc->IsNot(CT_SPACE)
          && is_past_width(pc))
       {
-         if (  chunk_is_token(pc, CT_VBRACE_CLOSE) // don't break if a vbrace close
-            && chunk_is_last_on_line(pc))          // is the last chunk on its line
+         if (  pc->Is(CT_VBRACE_CLOSE)  // don't break if a vbrace close
+            && pc->IsLastChunkOnLine()) // is the last chunk on its line
          {
             continue;
          }
@@ -176,13 +206,13 @@ void do_code_width(void)
 
          if (split_OK)
          {
-            LOG_FMT(LSPLIT, "%s(%d): orig_line is %zu, orig_col is %zu, Text() '%s'\n",
-                    __func__, __LINE__, pc->orig_line, pc->orig_col, pc->Text());
+            LOG_FMT(LSPLIT, "%s(%d): orig line is %zu, orig col is %zu, Text() '%s'\n",
+                    __func__, __LINE__, pc->GetOrigLine(), pc->GetOrigCol(), pc->Text());
          }
          else
          {
-            LOG_FMT(LSPLIT, "%s(%d): Bailed! orig_line is %zu, orig_col is %zu, Text() '%s'\n",
-                    __func__, __LINE__, pc->orig_line, pc->orig_col, pc->Text());
+            LOG_FMT(LSPLIT, "%s(%d): Bailed! orig line is %zu, orig col is %zu, Text() '%s'\n",
+                    __func__, __LINE__, pc->GetOrigLine(), pc->GetOrigCol(), pc->Text());
             break;
          }
       }
@@ -190,7 +220,7 @@ void do_code_width(void)
 }
 
 
-static const token_pri pri_table[] =
+static const TokenPriority pri_table[] =
 {
    { CT_SEMICOLON,    1 },
    { CT_COMMA,        2 },
@@ -230,12 +260,12 @@ static size_t get_split_pri(E_Token tok)
 }
 
 
-static void try_split_here(cw_entry &ent, Chunk *pc)
+static void try_split_here(SplitEntry &ent, Chunk *pc)
 {
    LOG_FUNC_ENTRY();
 
-   LOG_FMT(LSPLIT, "%s(%d): at %s, orig_col=%zu\n", __func__, __LINE__, pc->Text(), pc->orig_col);
-   size_t pc_pri = get_split_pri(pc->type);
+   LOG_FMT(LSPLIT, "%s(%d): at %s, orig col=%zu\n", __func__, __LINE__, pc->Text(), pc->GetOrigCol());
+   size_t pc_pri = get_split_pri(pc->GetType());
 
    LOG_FMT(LSPLIT, "%s(%d): pc_pri is %zu\n", __func__, __LINE__, pc_pri);
 
@@ -248,25 +278,25 @@ static void try_split_here(cw_entry &ent, Chunk *pc)
    // Can't split after a newline
    Chunk *prev = pc->GetPrev();
 
-   if (  prev == nullptr
-      || (  chunk_is_newline(prev)
-         && chunk_is_not_token(pc, CT_STRING)))
+   if (  prev->IsNullChunk()
+      || (  prev->IsNewline()
+         && pc->IsNot(CT_STRING)))
    {
-      if (prev != nullptr)
+      if (prev->IsNotNullChunk())
       {
-         LOG_FMT(LSPLIT, "%s(%d): Can't split after a newline, orig_line is %zu, return\n",
-                 __func__, __LINE__, prev->orig_line);
+         LOG_FMT(LSPLIT, "%s(%d): Can't split after a newline, orig line is %zu, return\n",
+                 __func__, __LINE__, prev->GetOrigLine());
       }
       return;
    }
    LOG_FMT(LSPLIT, "%s(%d):\n", __func__, __LINE__);
 
    // Can't split a function without arguments
-   if (chunk_is_token(pc, CT_FPAREN_OPEN))
+   if (pc->Is(CT_FPAREN_OPEN))
    {
       Chunk *next = pc->GetNext();
 
-      if (chunk_is_token(next, CT_FPAREN_CLOSE))
+      if (next->Is(CT_FPAREN_CLOSE))
       {
          LOG_FMT(LSPLIT, "%s(%d): Can't split a function without arguments, return\n", __func__, __LINE__);
          return;
@@ -275,11 +305,11 @@ static void try_split_here(cw_entry &ent, Chunk *pc)
    LOG_FMT(LSPLIT, "%s(%d):\n", __func__, __LINE__);
 
    // Only split concatenated strings
-   if (chunk_is_token(pc, CT_STRING))
+   if (pc->Is(CT_STRING))
    {
       Chunk *next = pc->GetNext();
 
-      if (chunk_is_not_token(next, CT_STRING))
+      if (next->IsNot(CT_STRING))
       {
          LOG_FMT(LSPLIT, "%s(%d): Only split concatenated strings, return\n", __func__, __LINE__);
          return;
@@ -303,8 +333,8 @@ static void try_split_here(cw_entry &ent, Chunk *pc)
    {
       Chunk *next = pc->GetNext();
 
-      if (  chunk_is_not_token(next, CT_WORD)
-         && (get_split_pri(next->type) != 25))
+      if (  next->IsNot(CT_WORD)
+         && (get_split_pri(next->GetType()) != 25))
       {
          LOG_FMT(LSPLIT, "%s(%d): don't break after last term of a qualified type, return\n", __func__, __LINE__);
          return;
@@ -314,8 +344,8 @@ static void try_split_here(cw_entry &ent, Chunk *pc)
    // Check levels first
    bool change = false;
 
-   if (  ent.pc == nullptr
-      || pc->level < ent.pc->level)
+   if (  ent.pc->IsNullChunk()
+      || pc->GetLevel() < ent.pc->GetLevel())
    {
       LOG_FMT(LSPLIT, "%s(%d):\n", __func__, __LINE__);
       change = true;
@@ -342,18 +372,18 @@ static void try_split_here(cw_entry &ent, Chunk *pc)
 static bool split_line(Chunk *start)
 {
    LOG_FUNC_ENTRY();
-   LOG_FMT(LSPLIT, "%s(%d): start->Text() '%s', orig_line is %zu, orig_col is %zu, type is %s\n",
-           __func__, __LINE__, start->Text(), start->orig_line, start->orig_col, get_token_name(start->type));
-   LOG_FMT(LSPLIT, "   start->flags ");
-   log_pcf_flags(LSPLIT, start->flags);
-   LOG_FMT(LSPLIT, "   start->parent_type %s, (PCF_IN_FCN_DEF is %s), (PCF_IN_FCN_CALL is %s)\n",
-           get_token_name(get_chunk_parent_type(start)),
-           start->flags.test((PCF_IN_FCN_DEF)) ? "TRUE" : "FALSE",
-           start->flags.test((PCF_IN_FCN_CALL)) ? "TRUE" : "FALSE");
+   LOG_FMT(LSPLIT, "%s(%d): start->Text() '%s', orig line is %zu, orig col is %zu, type is %s\n",
+           __func__, __LINE__, start->Text(), start->GetOrigLine(), start->GetOrigCol(), get_token_name(start->GetType()));
+   LOG_FMT(LSPLIT, "   start->GetFlags() ");
+   log_pcf_flags(LSPLIT, start->GetFlags());
+   LOG_FMT(LSPLIT, "   start->GetParentType() %s, (PCF_IN_FCN_DEF is %s), (PCF_IN_FCN_CALL is %s)\n",
+           get_token_name(start->GetParentType()),
+           start->TestFlags((PCF_IN_FCN_DEF)) ? "TRUE" : "FALSE",
+           start->TestFlags((PCF_IN_FCN_CALL)) ? "TRUE" : "FALSE");
 
    // break at maximum line length if ls_code_width is true
    // Issue #2432
-   if (start->flags.test(PCF_ONE_LINER))
+   if (start->TestFlags(PCF_ONE_LINER))
    {
       LOG_FMT(LSPLIT, "%s(%d): ** ONCE LINER SPLIT **\n", __func__, __LINE__);
       undo_one_liner(start);
@@ -370,7 +400,7 @@ static bool split_line(Chunk *start)
    {
    }
    // Check to see if we are in a for statement
-   else if (start->flags.test(PCF_IN_FOR))
+   else if (start->TestFlags(PCF_IN_FOR))
    {
       LOG_FMT(LSPLIT, " ** FOR SPLIT **\n");
       split_for_stmt(start);
@@ -386,10 +416,10 @@ static bool split_line(Chunk *start)
     * If this is in a function call or prototype, split on commas or right
     * after the open parenthesis
     */
-   else if (  start->flags.test(PCF_IN_FCN_DEF)
-           || get_chunk_parent_type(start) == CT_FUNC_PROTO            // Issue #1169
-           || (  (start->level == (start->brace_level + 1))
-              && start->flags.test(PCF_IN_FCN_CALL)))
+   else if (  start->TestFlags(PCF_IN_FCN_DEF)
+           || start->GetParentType() == CT_FUNC_PROTO            // Issue #1169
+           || (  (start->GetLevel() == (start->GetBraceLevel() + 1))
+              && start->TestFlags(PCF_IN_FCN_CALL)))
    {
       LOG_FMT(LSPLIT, " ** FUNC SPLIT **\n");
 
@@ -411,7 +441,7 @@ static bool split_line(Chunk *start)
    /*
     * If this is in a template, split on commas, Issue #1170
     */
-   else if (start->flags.test(PCF_IN_TEMPLATE))
+   else if (start->TestFlags(PCF_IN_TEMPLATE))
    {
       LOG_FMT(LSPLIT, " ** TEMPLATE SPLIT **\n");
       split_template(start);
@@ -419,51 +449,51 @@ static bool split_line(Chunk *start)
    }
    LOG_FMT(LSPLIT, "%s(%d):\n", __func__, __LINE__);
    // Try to find the best spot to split the line
-   cw_entry ent;
+   SplitEntry ent;
+   Chunk      *pc = start;
+   Chunk      *prev;
 
-   memset(&ent, 0, sizeof(ent));
-   Chunk *pc = start;
-   Chunk *prev;
+   pc = pc->GetPrev();
 
-   while (  ((pc = pc->GetPrev()) != nullptr)
-         && pc->IsNotNullChunk()
-         && !chunk_is_newline(pc))
+   while (  pc->IsNotNullChunk()
+         && !pc->IsNewline())
    {
-      LOG_FMT(LSPLIT, "%s(%d): at %s, orig_line is %zu, orig_col is %zu\n",
-              __func__, __LINE__, pc->Text(), pc->orig_line, pc->orig_col);
+      LOG_FMT(LSPLIT, "%s(%d): at %s, orig line is %zu, orig col is %zu\n",
+              __func__, __LINE__, pc->Text(), pc->GetOrigLine(), pc->GetOrigCol());
 
-      if (chunk_is_not_token(pc, CT_SPACE))
+      if (pc->IsNot(CT_SPACE))
       {
          try_split_here(ent, pc);
 
          // break at maximum line length
          log_rule_B("ls_code_width");
 
-         if (  ent.pc != nullptr
+         if (  ent.pc->IsNotNullChunk()
             && (options::ls_code_width()))
          {
             break;
          }
       }
+      pc = pc->GetPrev();
    }
 
-   if (ent.pc == nullptr)
+   if (ent.pc->IsNullChunk())
    {
-      LOG_FMT(LSPLIT, "%s(%d):    TRY_SPLIT yielded NO SOLUTION for orig_line %zu at '%s' [%s]\n",
-              __func__, __LINE__, start->orig_line, start->Text(), get_token_name(start->type));
+      LOG_FMT(LSPLIT, "%s(%d):    TRY_SPLIT yielded NO SOLUTION for orig line %zu at '%s' [%s]\n",
+              __func__, __LINE__, start->GetOrigLine(), start->Text(), get_token_name(start->GetType()));
    }
    else
    {
-      LOG_FMT(LSPLIT, "%s(%d):    TRY_SPLIT yielded '%s' [%s] on orig_line %zu\n",
-              __func__, __LINE__, ent.pc->Text(), get_token_name(ent.pc->type), ent.pc->orig_line);
-      LOG_FMT(LSPLIT, "%s(%d): ent at '%s', orig_col is %zu\n",
-              __func__, __LINE__, ent.pc->Text(), ent.pc->orig_col);
+      LOG_FMT(LSPLIT, "%s(%d):    TRY_SPLIT yielded '%s' [%s] on orig line %zu\n",
+              __func__, __LINE__, ent.pc->Text(), get_token_name(ent.pc->GetType()), ent.pc->GetOrigLine());
+      LOG_FMT(LSPLIT, "%s(%d): ent at '%s', orig col is %zu\n",
+              __func__, __LINE__, ent.pc->Text(), ent.pc->GetOrigCol());
    }
 
    // Break before the token instead of after it according to the pos_xxx rules
-   if (ent.pc == nullptr)
+   if (ent.pc->IsNullChunk())
    {
-      pc = nullptr;
+      pc = Chunk::NullChunkPtr;
    }
    else
    {
@@ -474,19 +504,19 @@ static bool split_line(Chunk *start)
       log_rule_B("pos_shift");
       log_rule_B("pos_bool");
 
-      if (  (  chunk_is_token(ent.pc, CT_SHIFT)
+      if (  (  ent.pc->Is(CT_SHIFT)
             && (options::pos_shift() & TP_LEAD))
-         || (  (  chunk_is_token(ent.pc, CT_ARITH)
-               || chunk_is_token(ent.pc, CT_CARET))
+         || (  (  ent.pc->Is(CT_ARITH)
+               || ent.pc->Is(CT_CARET))
             && (options::pos_arith() & TP_LEAD))
-         || (  chunk_is_token(ent.pc, CT_ASSIGN)
+         || (  ent.pc->Is(CT_ASSIGN)
             && (options::pos_assign() & TP_LEAD))
-         || (  chunk_is_token(ent.pc, CT_COMPARE)
+         || (  ent.pc->Is(CT_COMPARE)
             && (options::pos_compare() & TP_LEAD))
-         || (  (  chunk_is_token(ent.pc, CT_COND_COLON)
-               || chunk_is_token(ent.pc, CT_QUESTION))
+         || (  (  ent.pc->Is(CT_COND_COLON)
+               || ent.pc->Is(CT_QUESTION))
             && (options::pos_conditional() & TP_LEAD))
-         || (  chunk_is_token(ent.pc, CT_BOOL)
+         || (  ent.pc->Is(CT_BOOL)
             && (options::pos_bool() & TP_LEAD)))
       {
          pc = ent.pc;
@@ -495,27 +525,25 @@ static bool split_line(Chunk *start)
       {
          pc = ent.pc->GetNext();
       }
-      LOG_FMT(LSPLIT, "%s(%d): at '%s', orig_col is %zu\n",
-              __func__, __LINE__, pc->Text(), pc->orig_col);
+      LOG_FMT(LSPLIT, "%s(%d): at '%s', orig col is %zu\n",
+              __func__, __LINE__, pc->Text(), pc->GetOrigCol());
    }
 
-   if (  pc == nullptr
-      || pc->IsNullChunk())
+   if (pc->IsNullChunk())
    {
       pc = start;
 
       // Don't break before a close, comma, or colon
-      if (  chunk_is_token(start, CT_PAREN_CLOSE)
-         || chunk_is_token(start, CT_PAREN_OPEN)
-         || chunk_is_token(start, CT_FPAREN_CLOSE)
-         || chunk_is_token(start, CT_FPAREN_OPEN)
-         || chunk_is_token(start, CT_SPAREN_CLOSE)
-         || chunk_is_token(start, CT_SPAREN_OPEN)
-         || chunk_is_token(start, CT_ANGLE_CLOSE)
-         || chunk_is_token(start, CT_BRACE_CLOSE)
-         || chunk_is_token(start, CT_COMMA)
-         || chunk_is_token(start, CT_SEMICOLON)
-         || chunk_is_token(start, CT_VSEMICOLON)
+      if (  start->Is(CT_PAREN_CLOSE)
+         || start->Is(CT_PAREN_OPEN)
+         || start->Is(CT_FPAREN_CLOSE)
+         || start->Is(CT_FPAREN_OPEN)
+         || start->Is(CT_SPAREN_CLOSE)
+         || start->Is(CT_SPAREN_OPEN)
+         || start->Is(CT_ANGLE_CLOSE)
+         || start->Is(CT_BRACE_CLOSE)
+         || start->Is(CT_COMMA)
+         || start->IsSemicolon()
          || start->Len() == 0)
       {
          LOG_FMT(LSPLIT, " ** NO GO **\n");
@@ -527,19 +555,18 @@ static bool split_line(Chunk *start)
    // add a newline before pc
    prev = pc->GetPrev();
 
-   if (  prev != nullptr
-      && prev->IsNotNullChunk()
-      && !chunk_is_newline(pc)
-      && !chunk_is_newline(prev))
+   if (  prev->IsNotNullChunk()
+      && !pc->IsNewline()
+      && !prev->IsNewline())
    {
       //int plen = (pc->Len() < 5) ? pc->Len() : 5;
       //int slen = (start->Len() < 5) ? start->Len() : 5;
       //LOG_FMT(LSPLIT, " '%.*s' [%s], started on token '%.*s' [%s]\n",
-      //        plen, pc->Text(), get_token_name(pc->type),
-      //        slen, start->Text(), get_token_name(start->type));
+      //        plen, pc->Text(), get_token_name(pc->GetType()),
+      //        slen, start->Text(), get_token_name(start->GetType()));
       LOG_FMT(LSPLIT, "%s(%d): Text() '%s', type %s, started on token '%s', type %s\n",
-              __func__, __LINE__, pc->Text(), get_token_name(pc->type),
-              start->Text(), get_token_name(start->type));
+              __func__, __LINE__, pc->Text(), get_token_name(pc->GetType()),
+              start->Text(), get_token_name(start->GetType()));
 
       split_before_chunk(pc);
    }
@@ -561,31 +588,30 @@ static void split_for_stmt(Chunk *start)
    // how many semicolons (1 or 2) do we need to find
    log_rule_B("ls_for_split_full");
    size_t max_cnt     = options::ls_for_split_full() ? 2 : 1;
-   Chunk  *open_paren = nullptr;
+   Chunk  *open_paren = Chunk::NullChunkPtr;
    size_t nl_cnt      = 0;
 
    LOG_FMT(LSPLIT, "%s: starting on %s, line %zu\n",
-           __func__, start->Text(), start->orig_line);
+           __func__, start->Text(), start->GetOrigLine());
 
    // Find the open paren so we know the level and count newlines
    Chunk *pc = start;
 
-   while (  ((pc = pc->GetPrev()) != nullptr)
-         && pc->IsNotNullChunk())
+   while ((pc = pc->GetPrev())->IsNotNullChunk())
    {
-      if (chunk_is_token(pc, CT_SPAREN_OPEN))
+      if (pc->Is(CT_SPAREN_OPEN))
       {
          open_paren = pc;
          break;
       }
 
-      if (pc->nl_count > 0)
+      if (pc->GetNlCount() > 0)
       {
-         nl_cnt += pc->nl_count;
+         nl_cnt += pc->GetNlCount();
       }
    }
 
-   if (open_paren == nullptr)
+   if (open_paren->IsNullChunk())
    {
       LOG_FMT(LSPLIT, "No open paren\n");
       return;
@@ -596,20 +622,20 @@ static void split_for_stmt(Chunk *start)
 
    pc = start;
 
-   if (  chunk_is_token(pc, CT_SEMICOLON)
-      && get_chunk_parent_type(pc) == CT_FOR)
+   if (  pc->Is(CT_SEMICOLON)
+      && pc->GetParentType() == CT_FOR)
    {
       st[count++] = pc;
    }
 
    // first scan backwards for the semicolons
    while (  (count < static_cast<int>(max_cnt))
-         && ((pc = pc->GetPrev()) != nullptr)
+         && ((pc = pc->GetPrev())->IsNotNullChunk())
          && pc->IsNotNullChunk()
-         && pc->flags.test(PCF_IN_SPAREN))
+         && pc->TestFlags(PCF_IN_SPAREN))
    {
-      if (  chunk_is_token(pc, CT_SEMICOLON)
-         && get_chunk_parent_type(pc) == CT_FOR)
+      if (  pc->Is(CT_SEMICOLON)
+         && pc->GetParentType() == CT_FOR)
       {
          st[count++] = pc;
       }
@@ -619,10 +645,10 @@ static void split_for_stmt(Chunk *start)
 
    while (  (count < static_cast<int>(max_cnt))
          && ((pc = pc->GetNext())->IsNotNullChunk())
-         && pc->flags.test(PCF_IN_SPAREN))
+         && pc->TestFlags(PCF_IN_SPAREN))
    {
-      if (  chunk_is_token(pc, CT_SEMICOLON)
-         && get_chunk_parent_type(pc) == CT_FOR)
+      if (  pc->Is(CT_SEMICOLON)
+         && pc->GetParentType() == CT_FOR)
       {
          st[count++] = pc;
       }
@@ -640,13 +666,13 @@ static void split_for_stmt(Chunk *start)
    {
       return;
    }
-   // Still past width, check for commas at parenthese level
+   // Still past width, check for commas at parentheses level
    pc = open_paren;
 
    while ((pc = pc->GetNext()) != start)
    {
-      if (  chunk_is_token(pc, CT_COMMA)
-         && (pc->level == (open_paren->level + 1)))
+      if (  pc->Is(CT_COMMA)
+         && (pc->GetLevel() == (open_paren->GetLevel() + 1)))
       {
          split_before_chunk(pc->GetNext());
 
@@ -656,13 +682,13 @@ static void split_for_stmt(Chunk *start)
          }
       }
    }
-   // Still past width, check for a assignments at parenthese level
+   // Still past width, check for a assignments at parentheses level
    pc = open_paren;
 
    while ((pc = pc->GetNext()) != start)
    {
-      if (  chunk_is_token(pc, CT_ASSIGN)
-         && (pc->level == (open_paren->level + 1)))
+      if (  pc->Is(CT_ASSIGN)
+         && (pc->GetLevel() == (open_paren->GetLevel() + 1)))
       {
          split_before_chunk(pc->GetNext());
 
@@ -686,14 +712,13 @@ static void split_fcn_params_full(Chunk *start)
 
    LOG_FMT(LSPLIT, "  %s(%d): Find the opening function parenthesis\n", __func__, __LINE__);
 
-   while (  (fpo = fpo->GetPrev()) != nullptr
-         && fpo->IsNotNullChunk())
+   while ((fpo = fpo->GetPrev())->IsNotNullChunk())
    {
-      LOG_FMT(LSPLIT, "%s(%d): %s, orig_col is %zu, level is %zu\n",
-              __func__, __LINE__, fpo->Text(), fpo->orig_col, fpo->level);
+      LOG_FMT(LSPLIT, "%s(%d): %s, orig col is %zu, level is %zu\n",
+              __func__, __LINE__, fpo->Text(), fpo->GetOrigCol(), fpo->GetLevel());
 
-      if (  chunk_is_token(fpo, CT_FPAREN_OPEN)
-         && (fpo->level == start->level - 1))
+      if (  fpo->Is(CT_FPAREN_OPEN)
+         && (fpo->GetLevel() == start->GetLevel() - 1))
       {
          break;  // opening parenthesis found. Issue #1020
       }
@@ -703,13 +728,13 @@ static void split_fcn_params_full(Chunk *start)
 
    while (pc->IsNotNullChunk())
    {
-      if (pc->level <= fpo->level)
+      if (pc->GetLevel() <= fpo->GetLevel())
       {
          break;
       }
 
-      if (  (pc->level == (fpo->level + 1))
-         && chunk_is_token(pc, CT_COMMA))
+      if (  (pc->GetLevel() == (fpo->GetLevel() + 1))
+         && pc->Is(CT_COMMA))
       {
          split_before_chunk(pc->GetNext());
       }
@@ -721,26 +746,28 @@ static void split_fcn_params_full(Chunk *start)
 static void split_fcn_params(Chunk *start)
 {
    LOG_FUNC_ENTRY();
-   LOG_FMT(LSPLIT, "%s(%d): start->Text() is '%s', orig_line is %zu, orig_col is %zu\n",
-           __func__, __LINE__, start->Text(), start->orig_line, start->orig_col);
+   LOG_FMT(LSPLIT, "%s(%d): start->Text() is '%s', orig line is %zu, orig col is %zu\n",
+           __func__, __LINE__, start->Text(), start->GetOrigLine(), start->GetOrigCol());
    Chunk *fpo = start;
 
-   if (!chunk_is_token(start, CT_FPAREN_OPEN))
+   if (!start->Is(CT_FPAREN_OPEN))
    {
       // Find the opening function parenthesis
       LOG_FMT(LSPLIT, "%s(%d): Find the opening function parenthesis\n", __func__, __LINE__);
 
-      while (  ((fpo = fpo->GetPrev()) != nullptr)
-            && fpo->IsNotNullChunk()
-            && chunk_is_not_token(fpo, CT_FPAREN_OPEN))
+      fpo = fpo->GetPrev();
+
+      while (  fpo->IsNotNullChunk()
+            && fpo->IsNot(CT_FPAREN_OPEN))
       {
          // do nothing
-         LOG_FMT(LSPLIT, "%s(%d): '%s', orig_col is %zu, level is %zu\n",
-                 __func__, __LINE__, fpo->Text(), fpo->orig_col, fpo->level);
+         LOG_FMT(LSPLIT, "%s(%d): '%s', orig col is %zu, level is %zu\n",
+                 __func__, __LINE__, fpo->Text(), fpo->GetOrigCol(), fpo->GetLevel());
+         fpo = fpo->GetPrev();
       }
    }
    Chunk  *pc     = fpo->GetNextNcNnl();
-   size_t min_col = pc->column;
+   size_t min_col = pc->GetColumn();
 
    log_rule_B("code_width");
    LOG_FMT(LSPLIT, "    mincol is %zu, max_width is %zu\n",
@@ -753,10 +780,9 @@ static void split_fcn_params(Chunk *start)
 
    while (pc->IsNotNullChunk())
    {
-      LOG_FMT(LSPLIT, "%s(%d): pc->Text() '%s', type is %s\n",
-              __func__, __LINE__, pc->Text(), get_token_name(pc->type));
+      LOG_CHUNK(LTOK, pc);
 
-      if (chunk_is_newline(pc))
+      if (pc->IsNewline())
       {
          cur_width = 0;
          last_col  = -1;
@@ -765,23 +791,23 @@ static void split_fcn_params(Chunk *start)
       {
          if (last_col < 0)
          {
-            last_col = pc->column;
+            last_col = pc->GetColumn();
             LOG_FMT(LSPLIT, "%s(%d): last_col is %d\n",
                     __func__, __LINE__, last_col);
          }
-         cur_width += (pc->column - last_col) + pc->Len();
-         last_col   = pc->column + pc->Len();
+         cur_width += (pc->GetColumn() - last_col) + pc->Len();
+         last_col   = pc->GetColumn() + pc->Len();
 
          LOG_FMT(LSPLIT, "%s(%d): last_col is %d\n",
                  __func__, __LINE__, last_col);
 
-         if (  chunk_is_token(pc, CT_COMMA)
-            || chunk_is_token(pc, CT_FPAREN_CLOSE))
+         if (  pc->Is(CT_COMMA)
+            || pc->Is(CT_FPAREN_CLOSE))
          {
             if (cur_width == 0)
             {
                fprintf(stderr, "%s(%d): cur_width is ZERO, cannot be decremented, at line %zu, column %zu\n",
-                       __func__, __LINE__, pc->orig_line, pc->orig_col);
+                       __func__, __LINE__, pc->GetOrigLine(), pc->GetOrigCol());
                log_flush(true);
                exit(EX_SOFTWARE);
             }
@@ -792,7 +818,7 @@ static void split_fcn_params(Chunk *start)
             log_rule_B("code_width");
 
             if (  ((last_col - 1) > static_cast<int>(options::code_width()))
-               || chunk_is_token(pc, CT_FPAREN_CLOSE))
+               || pc->Is(CT_FPAREN_CLOSE))
             {
                break;
             }
@@ -804,20 +830,20 @@ static void split_fcn_params(Chunk *start)
    Chunk *prev = pc;
 
    LOG_FMT(LSPLIT, "%s(%d): back up until the prev is a comma, begin is '%s', level is %zu\n",
-           __func__, __LINE__, prev->Text(), prev->level);
+           __func__, __LINE__, prev->Text(), prev->GetLevel());
 
    while ((prev = prev->GetPrev())->IsNotNullChunk())
    {
-      LOG_FMT(LSPLIT, "%s(%d): prev->Text() is '%s', prev->orig_line is %zu, prev->orig_col is %zu\n",
-              __func__, __LINE__, prev->Text(), prev->orig_line, prev->orig_col);
-      LOG_FMT(LSPLIT, "%s(%d): prev->level is %zu, prev '%s', prev->type is %s\n",
-              __func__, __LINE__, prev->level, prev->Text(), get_token_name(prev->type));
+      LOG_FMT(LSPLIT, "%s(%d): prev->Text() is '%s', orig line is %zu, orig col is %zu\n",
+              __func__, __LINE__, prev->Text(), prev->GetOrigLine(), prev->GetOrigCol());
+      LOG_FMT(LSPLIT, "%s(%d): prev->GetLevel() is %zu, prev '%s', prev->GetType() is %s\n",
+              __func__, __LINE__, prev->GetLevel(), prev->Text(), get_token_name(prev->GetType()));
 
-      if (  chunk_is_newline(prev)
-         || chunk_is_token(prev, CT_COMMA))
+      if (  prev->IsNewline()
+         || prev->Is(CT_COMMA))
       {
          LOG_FMT(LSPLIT, "%s(%d): found at %zu\n",
-                 __func__, __LINE__, prev->orig_col);
+                 __func__, __LINE__, prev->GetOrigCol());
          break;
       }
       LOG_FMT(LSPLIT, "%s(%d): last_col is %d, prev->Len() is %zu\n",
@@ -826,7 +852,7 @@ static void split_fcn_params(Chunk *start)
       LOG_FMT(LSPLIT, "%s(%d): last_col is %d\n",
               __func__, __LINE__, last_col);
 
-      if (chunk_is_token(prev, CT_FPAREN_OPEN))
+      if (prev->Is(CT_FPAREN_OPEN))
       {
          pc = prev->GetNext();
 
@@ -835,7 +861,7 @@ static void split_fcn_params(Chunk *start)
          if (!options::indent_paren_nl())
          {
             log_rule_B("indent_columns");
-            min_col = pc->brace_level * options::indent_columns() + 1;
+            min_col = pc->GetBraceLevel() * options::indent_columns() + 1;
             LOG_FMT(LSPLIT, "%s(%d): min_col is %zu\n",
                     __func__, __LINE__, min_col);
 
@@ -855,7 +881,7 @@ static void split_fcn_params(Chunk *start)
          }
 
          // Don't split "()"
-         if (pc->type != E_Token(prev->type + 1))
+         if (pc->GetType() != E_Token(prev->GetType() + 1))
          {
             break;
          }
@@ -863,15 +889,40 @@ static void split_fcn_params(Chunk *start)
    }
 
    if (  prev->IsNotNullChunk()
-      && !chunk_is_newline(prev))
+      && !prev->IsNewline())
    {
       LOG_FMT(LSPLIT, "%s(%d): -- ended on %s --\n",
-              __func__, __LINE__, get_token_name(prev->type));
+              __func__, __LINE__, get_token_name(prev->GetType()));
       LOG_FMT(LSPLIT, "%s(%d): min_col is %zu\n",
               __func__, __LINE__, min_col);
       pc = prev->GetNext();
+
+      if (  prev->Is(CT_PAREN_OPEN)
+         || prev->Is(CT_LPAREN_OPEN)
+         || prev->Is(CT_SPAREN_OPEN)
+         || prev->Is(CT_FPAREN_OPEN)
+         || prev->Is(CT_SQUARE_OPEN)
+         || prev->Is(CT_ANGLE_OPEN))
+      {
+         // Mark open and close parens as continuation line chunks.
+         // This will prevent an additional level and frame to be
+         // added to the current frame stack (issue 3105).
+         LOG_FMT(LSPLIT, "%s(%d): set PCF_LINE_CONT for prev text '%s', orig line is %zu, orig col is %zu\n",
+                 __func__, __LINE__, prev->Text(), prev->GetOrigLine(), prev->GetOrigCol());
+
+         prev->SetFlagBits(PCF_CONT_LINE);
+         Chunk *closing_paren = prev->GetClosingParen();
+
+         if (closing_paren->IsNotNullChunk())
+         {
+            closing_paren->SetFlagBits(PCF_CONT_LINE);
+         }
+      }
       newline_add_before(pc);
       reindent_line(pc, min_col);
+      // Mark chunk as continuation line, so indentation can be
+      // correctly set over multiple passes
+      pc->SetFlagBits(PCF_CONT_LINE);
       cpd.changes++;
    }
 } // split_fcn_params
@@ -890,18 +941,18 @@ static void split_template(Chunk *start)
    {
       LOG_FMT(LSPLIT, "  %s(%d): prev '%s'\n", __func__, __LINE__, prev->Text());
 
-      if (  chunk_is_newline(prev)
-         || chunk_is_token(prev, CT_COMMA))
+      if (  prev->IsNewline()
+         || prev->Is(CT_COMMA))
       {
          break;
       }
    }
 
-   if (  prev != nullptr
-      && !chunk_is_newline(prev))
+   if (  prev->IsNotNullChunk()
+      && !prev->IsNewline())
    {
       LOG_FMT(LSPLIT, "  %s(%d):", __func__, __LINE__);
-      LOG_FMT(LSPLIT, " -- ended on %s --\n", get_token_name(prev->type));
+      LOG_FMT(LSPLIT, " -- ended on %s --\n", get_token_name(prev->GetType()));
       Chunk  *pc = prev->GetNext();
       newline_add_before(pc);
       size_t min_col = 1;
